@charset "UTF-8";
/*!
 * Font Awesome Free 6.7.2 by @fontawesome - https://fontawesome.com
 * License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License)
 * Copyright 2024 Fonticons, Inc.
 */
.fa {
  font-family: var(--fa-style-family, "Font Awesome 6 Free");
  font-weight: var(--fa-style, 900);
}

.fas, [class^="icon-"], [class*=" icon-"], .far, .fab, .icon-joomla, .fa-solid, .fa-regular, .fa-brands, .fa {
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  display: var(--fa-display, inline-block);
  font-variant: normal;
  text-rendering: auto;
  font-style: normal;
  line-height: 1;
}

.fas:before, [class^="icon-"]:before, [class*=" icon-"]:before, .far:before, .fab:before, .icon-joomla:before, .fa-solid:before, .fa-regular:before, .fa-brands:before, .fa:before {
  content: var(--fa);
}

.fa-classic, .fas, [class^="icon-"], [class*=" icon-"], .fa-solid, .far, .fa-regular {
  font-family: "Font Awesome 6 Free";
}

.fa-brands, .fab, .icon-joomla {
  font-family: "Font Awesome 6 Brands";
}

.icon-joomla, [class^="icon-"], [class*=" icon-"] {
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  font-variant: normal;
  font-style: normal;
  font-weight: normal;
  line-height: 1;
  display: inline-block;
}

.fa-1x {
  font-size: 1em;
}

.fa-2x {
  font-size: 2em;
}

.fa-3x {
  font-size: 3em;
}

.fa-4x {
  font-size: 4em;
}

.fa-5x {
  font-size: 5em;
}

.fa-6x {
  font-size: 6em;
}

.fa-7x {
  font-size: 7em;
}

.fa-8x {
  font-size: 8em;
}

.fa-9x {
  font-size: 9em;
}

.fa-10x {
  font-size: 10em;
}

.fa-2xs {
  vertical-align: .225em;
  font-size: .625em;
  line-height: .1em;
}

.fa-xs, .icon-xs {
  vertical-align: .125em;
  font-size: .75em;
  line-height: .0833333em;
}

.fa-sm, .icon-sm {
  vertical-align: .0535714em;
  font-size: .875em;
  line-height: .0714286em;
}

.fa-lg, .icon-lg {
  vertical-align: -.075em;
  font-size: 1.25em;
  line-height: .05em;
}

.fa-xl {
  vertical-align: -.125em;
  font-size: 1.5em;
  line-height: .0416667em;
}

.fa-2xl {
  vertical-align: -.1875em;
  font-size: 2em;
  line-height: .03125em;
}

.fa-fw, .icon-fw {
  text-align: center;
  width: 1.25em;
}

.fa-ul, .icon-ul {
  margin-left: var(--fa-li-margin, 2.5em);
  padding-left: 0;
  list-style-type: none;
}

.fa-ul > li, .icon-ul > li {
  position: relative;
}

.fa-li, .icon-li {
  left: calc(-1 * var(--fa-li-width, 2em));
  text-align: center;
  width: var(--fa-li-width, 2em);
  line-height: inherit;
  position: absolute;
}

.fa-border, .icon-border {
  border-color: var(--fa-border-color, #eee);
  border-radius: var(--fa-border-radius, .1em);
  border-style: var(--fa-border-style, solid);
  border-width: var(--fa-border-width, .08em);
  padding: var(--fa-border-padding, .2em .25em .15em);
}

.fa-pull-left, .icon-pull-left {
  float: left;
  margin-right: var(--fa-pull-margin, .3em);
}

.fa-pull-right, .icon-pull-right {
  float: right;
  margin-left: var(--fa-pull-margin, .3em);
}

.fa-beat {
  animation-name: fa-beat;
  animation-delay: var(--fa-animation-delay, 0s);
  animation-direction: var(--fa-animation-direction, normal);
  animation-duration: var(--fa-animation-duration, 1s);
  animation-iteration-count: var(--fa-animation-iteration-count, infinite);
  animation-timing-function: var(--fa-animation-timing, ease-in-out);
}

.fa-bounce {
  animation-name: fa-bounce;
  animation-delay: var(--fa-animation-delay, 0s);
  animation-direction: var(--fa-animation-direction, normal);
  animation-duration: var(--fa-animation-duration, 1s);
  animation-iteration-count: var(--fa-animation-iteration-count, infinite);
  animation-timing-function: var(--fa-animation-timing, cubic-bezier(.28, .84, .42, 1));
}

.fa-fade {
  animation-name: fa-fade;
  animation-delay: var(--fa-animation-delay, 0s);
  animation-direction: var(--fa-animation-direction, normal);
  animation-duration: var(--fa-animation-duration, 1s);
  animation-iteration-count: var(--fa-animation-iteration-count, infinite);
  animation-timing-function: var(--fa-animation-timing, cubic-bezier(.4, 0, .6, 1));
}

.fa-beat-fade {
  animation-name: fa-beat-fade;
  animation-delay: var(--fa-animation-delay, 0s);
  animation-direction: var(--fa-animation-direction, normal);
  animation-duration: var(--fa-animation-duration, 1s);
  animation-iteration-count: var(--fa-animation-iteration-count, infinite);
  animation-timing-function: var(--fa-animation-timing, cubic-bezier(.4, 0, .6, 1));
}

.fa-flip {
  animation-name: fa-flip;
  animation-delay: var(--fa-animation-delay, 0s);
  animation-direction: var(--fa-animation-direction, normal);
  animation-duration: var(--fa-animation-duration, 1s);
  animation-iteration-count: var(--fa-animation-iteration-count, infinite);
  animation-timing-function: var(--fa-animation-timing, ease-in-out);
}

.fa-shake {
  animation-name: fa-shake;
  animation-delay: var(--fa-animation-delay, 0s);
  animation-direction: var(--fa-animation-direction, normal);
  animation-duration: var(--fa-animation-duration, 1s);
  animation-iteration-count: var(--fa-animation-iteration-count, infinite);
  animation-timing-function: var(--fa-animation-timing, linear);
}

.fa-spin, .icon-spin {
  animation-name: fa-spin;
  animation-delay: var(--fa-animation-delay, 0s);
  animation-direction: var(--fa-animation-direction, normal);
  animation-duration: var(--fa-animation-duration, 2s);
  animation-iteration-count: var(--fa-animation-iteration-count, infinite);
  animation-timing-function: var(--fa-animation-timing, linear);
}

.fa-spin-reverse {
  --fa-animation-direction: reverse;
}

.fa-pulse, .icon-pulse, .fa-spin-pulse {
  animation-name: fa-spin;
  animation-direction: var(--fa-animation-direction, normal);
  animation-duration: var(--fa-animation-duration, 1s);
  animation-iteration-count: var(--fa-animation-iteration-count, infinite);
  animation-timing-function: var(--fa-animation-timing, steps(8));
}

@media (prefers-reduced-motion: reduce) {
  .fa-beat, .fa-bounce, .fa-fade, .fa-beat-fade, .fa-flip, .fa-pulse, .icon-pulse, .fa-shake, .fa-spin, .icon-spin, .fa-spin-pulse {
    transition-duration: 0s;
    transition-delay: 0s;
    animation-duration: 1ms;
    animation-iteration-count: 1;
    animation-delay: -1ms;
  }
}

@keyframes fa-beat {
  0%, 90% {
    transform: scale(1);
  }

  45% {
    transform: scale(var(--fa-beat-scale, 1.25));
  }
}

@keyframes fa-bounce {
  0% {
    transform: scale(1)translateY(0);
  }

  10% {
    transform: scale(var(--fa-bounce-start-scale-x, 1.1), var(--fa-bounce-start-scale-y, .9)) translateY(0);
  }

  30% {
    transform: scale(var(--fa-bounce-jump-scale-x, .9), var(--fa-bounce-jump-scale-y, 1.1)) translateY(var(--fa-bounce-height, -.5em));
  }

  50% {
    transform: scale(var(--fa-bounce-land-scale-x, 1.05), var(--fa-bounce-land-scale-y, .95)) translateY(0);
  }

  57% {
    transform: scale(1, 1) translateY(var(--fa-bounce-rebound, -.125em));
  }

  64% {
    transform: scale(1)translateY(0);
  }

  100% {
    transform: scale(1)translateY(0);
  }
}

@keyframes fa-fade {
  50% {
    opacity: var(--fa-fade-opacity, .4);
  }
}

@keyframes fa-beat-fade {
  0%, 100% {
    opacity: var(--fa-beat-fade-opacity, .4);
    transform: scale(1);
  }

  50% {
    opacity: 1;
    transform: scale(var(--fa-beat-fade-scale, 1.125));
  }
}

@keyframes fa-flip {
  50% {
    transform: rotate3d(var(--fa-flip-x, 0), var(--fa-flip-y, 1), var(--fa-flip-z, 0), var(--fa-flip-angle, -180deg));
  }
}

@keyframes fa-shake {
  0% {
    transform: rotate(-15deg);
  }

  4% {
    transform: rotate(15deg);
  }

  8%, 24% {
    transform: rotate(-18deg);
  }

  12%, 28% {
    transform: rotate(18deg);
  }

  16% {
    transform: rotate(-22deg);
  }

  20% {
    transform: rotate(22deg);
  }

  32% {
    transform: rotate(-12deg);
  }

  36% {
    transform: rotate(12deg);
  }

  40%, 100% {
    transform: rotate(0);
  }
}

@keyframes fa-spin {
  0% {
    transform: rotate(0);
  }

  100% {
    transform: rotate(360deg);
  }
}

.fa-rotate-90, .icon-rotate-90 {
  transform: rotate(90deg);
}

.fa-rotate-180, .icon-rotate-180 {
  transform: rotate(180deg);
}

.fa-rotate-270, .icon-rotate-270 {
  transform: rotate(270deg);
}

.fa-flip-horizontal, .icon-flip-horizontal {
  transform: scale(-1, 1);
}

.fa-flip-vertical, .icon-flip-vertical {
  transform: scale(1, -1);
}

.fa-flip-both, .icon-flip-both, .fa-flip-horizontal.fa-flip-vertical, .fa-flip-horizontal.icon-flip-vertical, .fa-flip-vertical.icon-flip-horizontal, .icon-flip-horizontal.icon-flip-vertical {
  transform: scale(-1);
}

.fa-rotate-by {
  transform: rotate(var(--fa-rotate-angle, 0));
}

.fa-stack, .icon-stack {
  vertical-align: middle;
  width: 2.5em;
  height: 2em;
  line-height: 2em;
  display: inline-block;
  position: relative;
}

.fa-stack-1x, .icon-stack-1x, .fa-stack-2x, .icon-stack-2x {
  text-align: center;
  width: 100%;
  z-index: var(--fa-stack-z-index, auto);
  position: absolute;
  left: 0;
}

.fa-stack-1x, .icon-stack-1x {
  line-height: inherit;
}

.fa-stack-2x, .icon-stack-2x {
  font-size: 2em;
}

.fa-inverse, .icon-inverse {
  color: var(--fa-inverse, #fff);
}

.fa-0 {
  --fa: "0";
}

.fa-1 {
  --fa: "1";
}

.fa-2 {
  --fa: "2";
}

.fa-3 {
  --fa: "3";
}

.fa-4 {
  --fa: "4";
}

.fa-5 {
  --fa: "5";
}

.fa-6 {
  --fa: "6";
}

.fa-7 {
  --fa: "7";
}

.fa-8 {
  --fa: "8";
}

.fa-9 {
  --fa: "9";
}

.fa-fill-drip {
  --fa: "";
}

.fa-arrows-to-circle {
  --fa: "";
}

.fa-circle-chevron-right, .fa-chevron-circle-right {
  --fa: "";
}

.fa-at {
  --fa: "@";
}

.fa-trash-can, .fa-trash-alt {
  --fa: "";
}

.fa-text-height {
  --fa: "";
}

.fa-user-xmark, .fa-user-times {
  --fa: "";
}

.fa-stethoscope {
  --fa: "";
}

.fa-message, .fa-comment-alt {
  --fa: "";
}

.fa-info {
  --fa: "";
}

.fa-down-left-and-up-right-to-center, .fa-compress-alt {
  --fa: "";
}

.fa-explosion {
  --fa: "";
}

.fa-file-lines, .fa-file-alt, .fa-file-text {
  --fa: "";
}

.fa-wave-square {
  --fa: "";
}

.fa-ring {
  --fa: "";
}

.fa-building-un {
  --fa: "";
}

.fa-dice-three {
  --fa: "";
}

.fa-calendar-days, .fa-calendar-alt {
  --fa: "";
}

.fa-anchor-circle-check {
  --fa: "";
}

.fa-building-circle-arrow-right {
  --fa: "";
}

.fa-volleyball, .fa-volleyball-ball {
  --fa: "";
}

.fa-arrows-up-to-line {
  --fa: "";
}

.fa-sort-down, .fa-sort-desc {
  --fa: "";
}

.fa-circle-minus, .fa-minus-circle {
  --fa: "";
}

.fa-door-open {
  --fa: "";
}

.fa-right-from-bracket, .fa-sign-out-alt {
  --fa: "";
}

.fa-atom {
  --fa: "";
}

.fa-soap {
  --fa: "";
}

.fa-icons, .fa-heart-music-camera-bolt {
  --fa: "";
}

.fa-microphone-lines-slash, .fa-microphone-alt-slash {
  --fa: "";
}

.fa-bridge-circle-check {
  --fa: "";
}

.fa-pump-medical {
  --fa: "";
}

.fa-fingerprint {
  --fa: "";
}

.fa-hand-point-right {
  --fa: "";
}

.fa-magnifying-glass-location, .fa-search-location {
  --fa: "";
}

.fa-forward-step, .fa-step-forward {
  --fa: "";
}

.fa-face-smile-beam, .fa-smile-beam {
  --fa: "";
}

.fa-flag-checkered {
  --fa: "";
}

.fa-football, .fa-football-ball {
  --fa: "";
}

.fa-school-circle-exclamation {
  --fa: "";
}

.fa-crop {
  --fa: "";
}

.fa-angles-down, .fa-angle-double-down {
  --fa: "";
}

.fa-users-rectangle {
  --fa: "";
}

.fa-people-roof {
  --fa: "";
}

.fa-people-line {
  --fa: "";
}

.fa-beer-mug-empty, .fa-beer {
  --fa: "";
}

.fa-diagram-predecessor {
  --fa: "";
}

.fa-arrow-up-long, .fa-long-arrow-up {
  --fa: "";
}

.fa-fire-flame-simple, .fa-burn {
  --fa: "";
}

.fa-person, .fa-male {
  --fa: "";
}

.fa-laptop {
  --fa: "";
}

.fa-file-csv {
  --fa: "";
}

.fa-menorah {
  --fa: "";
}

.fa-truck-plane {
  --fa: "";
}

.fa-record-vinyl {
  --fa: "";
}

.fa-face-grin-stars, .fa-grin-stars {
  --fa: "";
}

.fa-bong {
  --fa: "";
}

.fa-spaghetti-monster-flying, .fa-pastafarianism {
  --fa: "";
}

.fa-arrow-down-up-across-line {
  --fa: "";
}

.fa-spoon, .fa-utensil-spoon {
  --fa: "";
}

.fa-jar-wheat {
  --fa: "";
}

.fa-envelopes-bulk, .fa-mail-bulk {
  --fa: "";
}

.fa-file-circle-exclamation {
  --fa: "";
}

.fa-circle-h, .fa-hospital-symbol {
  --fa: "";
}

.fa-pager {
  --fa: "";
}

.fa-address-book, .fa-contact-book {
  --fa: "";
}

.fa-strikethrough {
  --fa: "";
}

.fa-k {
  --fa: "K";
}

.fa-landmark-flag {
  --fa: "";
}

.fa-pencil, .fa-pencil-alt {
  --fa: "";
}

.fa-backward {
  --fa: "";
}

.fa-caret-right {
  --fa: "";
}

.fa-comments {
  --fa: "";
}

.fa-paste, .fa-file-clipboard {
  --fa: "";
}

.fa-code-pull-request {
  --fa: "";
}

.fa-clipboard-list {
  --fa: "";
}

.fa-truck-ramp-box, .fa-truck-loading {
  --fa: "";
}

.fa-user-check {
  --fa: "";
}

.fa-vial-virus {
  --fa: "";
}

.fa-sheet-plastic {
  --fa: "";
}

.fa-blog {
  --fa: "";
}

.fa-user-ninja {
  --fa: "";
}

.fa-person-arrow-up-from-line {
  --fa: "";
}

.fa-scroll-torah, .fa-torah {
  --fa: "";
}

.fa-broom-ball, .fa-quidditch, .fa-quidditch-broom-ball {
  --fa: "";
}

.fa-toggle-off {
  --fa: "";
}

.fa-box-archive, .fa-archive {
  --fa: "";
}

.fa-person-drowning {
  --fa: "";
}

.fa-arrow-down-9-1, .fa-sort-numeric-desc, .fa-sort-numeric-down-alt {
  --fa: "";
}

.fa-face-grin-tongue-squint, .fa-grin-tongue-squint {
  --fa: "";
}

.fa-spray-can {
  --fa: "";
}

.fa-truck-monster {
  --fa: "";
}

.fa-w {
  --fa: "W";
}

.fa-earth-africa, .fa-globe-africa {
  --fa: "";
}

.fa-rainbow {
  --fa: "";
}

.fa-circle-notch {
  --fa: "";
}

.fa-tablet-screen-button, .fa-tablet-alt {
  --fa: "";
}

.fa-paw {
  --fa: "";
}

.fa-cloud {
  --fa: "";
}

.fa-trowel-bricks {
  --fa: "";
}

.fa-face-flushed, .fa-flushed {
  --fa: "";
}

.fa-hospital-user {
  --fa: "";
}

.fa-tent-arrow-left-right {
  --fa: "";
}

.fa-gavel, .fa-legal {
  --fa: "";
}

.fa-binoculars {
  --fa: "";
}

.fa-microphone-slash {
  --fa: "";
}

.fa-box-tissue {
  --fa: "";
}

.fa-motorcycle {
  --fa: "";
}

.fa-bell-concierge, .fa-concierge-bell {
  --fa: "";
}

.fa-pen-ruler, .fa-pencil-ruler {
  --fa: "";
}

.fa-people-arrows, .fa-people-arrows-left-right {
  --fa: "";
}

.fa-mars-and-venus-burst {
  --fa: "";
}

.fa-square-caret-right, .fa-caret-square-right {
  --fa: "";
}

.fa-scissors, .fa-cut {
  --fa: "";
}

.fa-sun-plant-wilt {
  --fa: "";
}

.fa-toilets-portable {
  --fa: "";
}

.fa-hockey-puck {
  --fa: "";
}

.fa-table {
  --fa: "";
}

.fa-magnifying-glass-arrow-right {
  --fa: "";
}

.fa-tachograph-digital, .fa-digital-tachograph {
  --fa: "";
}

.fa-users-slash {
  --fa: "";
}

.fa-clover {
  --fa: "";
}

.fa-reply, .fa-mail-reply {
  --fa: "";
}

.fa-star-and-crescent {
  --fa: "";
}

.fa-house-fire {
  --fa: "";
}

.fa-square-minus, .fa-minus-square {
  --fa: "";
}

.fa-helicopter {
  --fa: "";
}

.fa-compass {
  --fa: "";
}

.fa-square-caret-down, .fa-caret-square-down {
  --fa: "";
}

.fa-file-circle-question {
  --fa: "";
}

.fa-laptop-code {
  --fa: "";
}

.fa-swatchbook {
  --fa: "";
}

.fa-prescription-bottle {
  --fa: "";
}

.fa-bars, .fa-navicon {
  --fa: "";
}

.fa-people-group {
  --fa: "";
}

.fa-hourglass-end, .fa-hourglass-3 {
  --fa: "";
}

.fa-heart-crack, .fa-heart-broken {
  --fa: "";
}

.fa-square-up-right, .fa-external-link-square-alt {
  --fa: "";
}

.fa-face-kiss-beam, .fa-kiss-beam {
  --fa: "";
}

.fa-film {
  --fa: "";
}

.fa-ruler-horizontal {
  --fa: "";
}

.fa-people-robbery {
  --fa: "";
}

.fa-lightbulb {
  --fa: "";
}

.fa-caret-left {
  --fa: "";
}

.fa-circle-exclamation, .fa-exclamation-circle {
  --fa: "";
}

.fa-school-circle-xmark {
  --fa: "";
}

.fa-arrow-right-from-bracket, .fa-sign-out {
  --fa: "";
}

.fa-circle-chevron-down, .fa-chevron-circle-down {
  --fa: "";
}

.fa-unlock-keyhole, .fa-unlock-alt {
  --fa: "";
}

.fa-cloud-showers-heavy {
  --fa: "";
}

.fa-headphones-simple, .fa-headphones-alt {
  --fa: "";
}

.fa-sitemap {
  --fa: "";
}

.fa-circle-dollar-to-slot, .fa-donate {
  --fa: "";
}

.fa-memory {
  --fa: "";
}

.fa-road-spikes {
  --fa: "";
}

.fa-fire-burner {
  --fa: "";
}

.fa-flag {
  --fa: "";
}

.fa-hanukiah {
  --fa: "";
}

.fa-feather {
  --fa: "";
}

.fa-volume-low, .fa-volume-down {
  --fa: "";
}

.fa-comment-slash {
  --fa: "";
}

.fa-cloud-sun-rain {
  --fa: "";
}

.fa-compress {
  --fa: "";
}

.fa-wheat-awn, .fa-wheat-alt {
  --fa: "";
}

.fa-ankh {
  --fa: "";
}

.fa-hands-holding-child {
  --fa: "";
}

.fa-asterisk {
  --fa: "*";
}

.fa-square-check, .fa-check-square {
  --fa: "";
}

.fa-peseta-sign {
  --fa: "";
}

.fa-heading, .fa-header {
  --fa: "";
}

.fa-ghost {
  --fa: "";
}

.fa-list, .fa-list-squares {
  --fa: "";
}

.fa-square-phone-flip, .fa-phone-square-alt {
  --fa: "";
}

.fa-cart-plus {
  --fa: "";
}

.fa-gamepad {
  --fa: "";
}

.fa-circle-dot, .fa-dot-circle {
  --fa: "";
}

.fa-face-dizzy, .fa-dizzy {
  --fa: "";
}

.fa-egg {
  --fa: "";
}

.fa-house-medical-circle-xmark {
  --fa: "";
}

.fa-campground {
  --fa: "";
}

.fa-folder-plus {
  --fa: "";
}

.fa-futbol, .fa-futbol-ball, .fa-soccer-ball {
  --fa: "";
}

.fa-paintbrush, .fa-paint-brush {
  --fa: "";
}

.fa-lock {
  --fa: "";
}

.fa-gas-pump {
  --fa: "";
}

.fa-hot-tub-person, .fa-hot-tub {
  --fa: "";
}

.fa-map-location, .fa-map-marked {
  --fa: "";
}

.fa-house-flood-water {
  --fa: "";
}

.fa-tree {
  --fa: "";
}

.fa-bridge-lock {
  --fa: "";
}

.fa-sack-dollar {
  --fa: "";
}

.fa-pen-to-square, .fa-edit {
  --fa: "";
}

.fa-car-side {
  --fa: "";
}

.fa-share-nodes, .fa-share-alt {
  --fa: "";
}

.fa-heart-circle-minus {
  --fa: "";
}

.fa-hourglass-half, .fa-hourglass-2 {
  --fa: "";
}

.fa-microscope {
  --fa: "";
}

.fa-sink {
  --fa: "";
}

.fa-bag-shopping, .fa-shopping-bag {
  --fa: "";
}

.fa-arrow-down-z-a, .fa-sort-alpha-desc, .fa-sort-alpha-down-alt {
  --fa: "";
}

.fa-mitten {
  --fa: "";
}

.fa-person-rays {
  --fa: "";
}

.fa-users {
  --fa: "";
}

.fa-eye-slash {
  --fa: "";
}

.fa-flask-vial {
  --fa: "";
}

.fa-hand, .fa-hand-paper {
  --fa: "";
}

.fa-om {
  --fa: "";
}

.fa-worm {
  --fa: "";
}

.fa-house-circle-xmark {
  --fa: "";
}

.fa-plug {
  --fa: "";
}

.fa-chevron-up {
  --fa: "";
}

.fa-hand-spock {
  --fa: "";
}

.fa-stopwatch {
  --fa: "";
}

.fa-face-kiss, .fa-kiss {
  --fa: "";
}

.fa-bridge-circle-xmark {
  --fa: "";
}

.fa-face-grin-tongue, .fa-grin-tongue {
  --fa: "";
}

.fa-chess-bishop {
  --fa: "";
}

.fa-face-grin-wink, .fa-grin-wink {
  --fa: "";
}

.fa-ear-deaf, .fa-deaf, .fa-deafness, .fa-hard-of-hearing {
  --fa: "";
}

.fa-road-circle-check {
  --fa: "";
}

.fa-dice-five {
  --fa: "";
}

.fa-square-rss, .fa-rss-square {
  --fa: "";
}

.fa-land-mine-on {
  --fa: "";
}

.fa-i-cursor {
  --fa: "";
}

.fa-stamp {
  --fa: "";
}

.fa-stairs {
  --fa: "";
}

.fa-i {
  --fa: "I";
}

.fa-hryvnia-sign, .fa-hryvnia {
  --fa: "";
}

.fa-pills {
  --fa: "";
}

.fa-face-grin-wide, .fa-grin-alt {
  --fa: "";
}

.fa-tooth {
  --fa: "";
}

.fa-v {
  --fa: "V";
}

.fa-bangladeshi-taka-sign {
  --fa: "";
}

.fa-bicycle {
  --fa: "";
}

.fa-staff-snake, .fa-rod-asclepius, .fa-rod-snake, .fa-staff-aesculapius {
  --fa: "";
}

.fa-head-side-cough-slash {
  --fa: "";
}

.fa-truck-medical, .fa-ambulance {
  --fa: "";
}

.fa-wheat-awn-circle-exclamation {
  --fa: "";
}

.fa-snowman {
  --fa: "";
}

.fa-mortar-pestle {
  --fa: "";
}

.fa-road-barrier {
  --fa: "";
}

.fa-school {
  --fa: "";
}

.fa-igloo {
  --fa: "";
}

.fa-joint {
  --fa: "";
}

.fa-angle-right {
  --fa: "";
}

.fa-horse {
  --fa: "";
}

.fa-q {
  --fa: "Q";
}

.fa-g {
  --fa: "G";
}

.fa-notes-medical {
  --fa: "";
}

.fa-temperature-half, .fa-temperature-2, .fa-thermometer-2, .fa-thermometer-half {
  --fa: "";
}

.fa-dong-sign {
  --fa: "";
}

.fa-capsules {
  --fa: "";
}

.fa-poo-storm, .fa-poo-bolt {
  --fa: "";
}

.fa-face-frown-open, .fa-frown-open {
  --fa: "";
}

.fa-hand-point-up {
  --fa: "";
}

.fa-money-bill {
  --fa: "";
}

.fa-bookmark {
  --fa: "";
}

.fa-align-justify {
  --fa: "";
}

.fa-umbrella-beach {
  --fa: "";
}

.fa-helmet-un {
  --fa: "";
}

.fa-bullseye {
  --fa: "";
}

.fa-bacon {
  --fa: "";
}

.fa-hand-point-down {
  --fa: "";
}

.fa-arrow-up-from-bracket {
  --fa: "";
}

.fa-folder, .fa-folder-blank {
  --fa: "";
}

.fa-file-waveform, .fa-file-medical-alt {
  --fa: "";
}

.fa-radiation {
  --fa: "";
}

.fa-chart-simple {
  --fa: "";
}

.fa-mars-stroke {
  --fa: "";
}

.fa-vial {
  --fa: "";
}

.fa-gauge, .fa-dashboard, .fa-gauge-med, .fa-tachometer-alt-average {
  --fa: "";
}

.fa-wand-magic-sparkles, .fa-magic-wand-sparkles {
  --fa: "";
}

.fa-e {
  --fa: "E";
}

.fa-pen-clip, .fa-pen-alt {
  --fa: "";
}

.fa-bridge-circle-exclamation {
  --fa: "";
}

.fa-user {
  --fa: "";
}

.fa-school-circle-check {
  --fa: "";
}

.fa-dumpster {
  --fa: "";
}

.fa-van-shuttle, .fa-shuttle-van {
  --fa: "";
}

.fa-building-user {
  --fa: "";
}

.fa-square-caret-left, .fa-caret-square-left {
  --fa: "";
}

.fa-highlighter {
  --fa: "";
}

.fa-key {
  --fa: "";
}

.fa-bullhorn {
  --fa: "";
}

.fa-globe {
  --fa: "";
}

.fa-synagogue {
  --fa: "";
}

.fa-person-half-dress {
  --fa: "";
}

.fa-road-bridge {
  --fa: "";
}

.fa-location-arrow {
  --fa: "";
}

.fa-c {
  --fa: "C";
}

.fa-tablet-button {
  --fa: "";
}

.fa-building-lock {
  --fa: "";
}

.fa-pizza-slice {
  --fa: "";
}

.fa-money-bill-wave {
  --fa: "";
}

.fa-chart-area, .fa-area-chart {
  --fa: "";
}

.fa-house-flag {
  --fa: "";
}

.fa-person-circle-minus {
  --fa: "";
}

.fa-ban, .fa-cancel {
  --fa: "";
}

.fa-camera-rotate {
  --fa: "";
}

.fa-spray-can-sparkles, .fa-air-freshener {
  --fa: "";
}

.fa-star {
  --fa: "";
}

.fa-repeat {
  --fa: "";
}

.fa-cross {
  --fa: "";
}

.fa-box {
  --fa: "";
}

.fa-venus-mars {
  --fa: "";
}

.fa-arrow-pointer, .fa-mouse-pointer {
  --fa: "";
}

.fa-maximize, .fa-expand-arrows-alt {
  --fa: "";
}

.fa-charging-station {
  --fa: "";
}

.fa-shapes, .fa-triangle-circle-square {
  --fa: "";
}

.fa-shuffle, .fa-random {
  --fa: "";
}

.fa-person-running, .fa-running {
  --fa: "";
}

.fa-mobile-retro {
  --fa: "";
}

.fa-grip-lines-vertical {
  --fa: "";
}

.fa-spider {
  --fa: "";
}

.fa-hands-bound {
  --fa: "";
}

.fa-file-invoice-dollar {
  --fa: "";
}

.fa-plane-circle-exclamation {
  --fa: "";
}

.fa-x-ray {
  --fa: "";
}

.fa-spell-check {
  --fa: "";
}

.fa-slash {
  --fa: "";
}

.fa-computer-mouse, .fa-mouse {
  --fa: "";
}

.fa-arrow-right-to-bracket, .fa-sign-in {
  --fa: "";
}

.fa-shop-slash, .fa-store-alt-slash {
  --fa: "";
}

.fa-server {
  --fa: "";
}

.fa-virus-covid-slash {
  --fa: "";
}

.fa-shop-lock {
  --fa: "";
}

.fa-hourglass-start, .fa-hourglass-1 {
  --fa: "";
}

.fa-blender-phone {
  --fa: "";
}

.fa-building-wheat {
  --fa: "";
}

.fa-person-breastfeeding {
  --fa: "";
}

.fa-right-to-bracket, .fa-sign-in-alt {
  --fa: "";
}

.fa-venus {
  --fa: "";
}

.fa-passport {
  --fa: "";
}

.fa-thumbtack-slash, .fa-thumb-tack-slash {
  --fa: "";
}

.fa-heart-pulse, .fa-heartbeat {
  --fa: "";
}

.fa-people-carry-box, .fa-people-carry {
  --fa: "";
}

.fa-temperature-high {
  --fa: "";
}

.fa-microchip {
  --fa: "";
}

.fa-crown {
  --fa: "";
}

.fa-weight-hanging {
  --fa: "";
}

.fa-xmarks-lines {
  --fa: "";
}

.fa-file-prescription {
  --fa: "";
}

.fa-weight-scale, .fa-weight {
  --fa: "";
}

.fa-user-group, .fa-user-friends {
  --fa: "";
}

.fa-arrow-up-a-z, .fa-sort-alpha-up {
  --fa: "";
}

.fa-chess-knight {
  --fa: "";
}

.fa-face-laugh-squint, .fa-laugh-squint {
  --fa: "";
}

.fa-wheelchair {
  --fa: "";
}

.fa-circle-arrow-up, .fa-arrow-circle-up {
  --fa: "";
}

.fa-toggle-on {
  --fa: "";
}

.fa-person-walking, .fa-walking {
  --fa: "";
}

.fa-l {
  --fa: "L";
}

.fa-fire {
  --fa: "";
}

.fa-bed-pulse, .fa-procedures {
  --fa: "";
}

.fa-shuttle-space, .fa-space-shuttle {
  --fa: "";
}

.fa-face-laugh, .fa-laugh {
  --fa: "";
}

.fa-folder-open {
  --fa: "";
}

.fa-heart-circle-plus {
  --fa: "";
}

.fa-code-fork {
  --fa: "";
}

.fa-city {
  --fa: "";
}

.fa-microphone-lines, .fa-microphone-alt {
  --fa: "";
}

.fa-pepper-hot {
  --fa: "";
}

.fa-unlock {
  --fa: "";
}

.fa-colon-sign {
  --fa: "";
}

.fa-headset {
  --fa: "";
}

.fa-store-slash {
  --fa: "";
}

.fa-road-circle-xmark {
  --fa: "";
}

.fa-user-minus {
  --fa: "";
}

.fa-mars-stroke-up, .fa-mars-stroke-v {
  --fa: "";
}

.fa-champagne-glasses, .fa-glass-cheers {
  --fa: "";
}

.fa-clipboard {
  --fa: "";
}

.fa-house-circle-exclamation {
  --fa: "";
}

.fa-file-arrow-up, .fa-file-upload {
  --fa: "";
}

.fa-wifi, .fa-wifi-3, .fa-wifi-strong {
  --fa: "";
}

.fa-bath, .fa-bathtub {
  --fa: "";
}

.fa-underline {
  --fa: "";
}

.fa-user-pen, .fa-user-edit {
  --fa: "";
}

.fa-signature {
  --fa: "";
}

.fa-stroopwafel {
  --fa: "";
}

.fa-bold {
  --fa: "";
}

.fa-anchor-lock {
  --fa: "";
}

.fa-building-ngo {
  --fa: "";
}

.fa-manat-sign {
  --fa: "";
}

.fa-not-equal {
  --fa: "";
}

.fa-border-top-left, .fa-border-style {
  --fa: "";
}

.fa-map-location-dot, .fa-map-marked-alt {
  --fa: "";
}

.fa-jedi {
  --fa: "";
}

.fa-square-poll-vertical, .fa-poll {
  --fa: "";
}

.fa-mug-hot {
  --fa: "";
}

.fa-car-battery, .fa-battery-car {
  --fa: "";
}

.fa-gift {
  --fa: "";
}

.fa-dice-two {
  --fa: "";
}

.fa-chess-queen {
  --fa: "";
}

.fa-glasses {
  --fa: "";
}

.fa-chess-board {
  --fa: "";
}

.fa-building-circle-check {
  --fa: "";
}

.fa-person-chalkboard {
  --fa: "";
}

.fa-mars-stroke-right, .fa-mars-stroke-h {
  --fa: "";
}

.fa-hand-back-fist, .fa-hand-rock {
  --fa: "";
}

.fa-square-caret-up, .fa-caret-square-up {
  --fa: "";
}

.fa-cloud-showers-water {
  --fa: "";
}

.fa-chart-bar, .fa-bar-chart {
  --fa: "";
}

.fa-hands-bubbles, .fa-hands-wash {
  --fa: "";
}

.fa-less-than-equal {
  --fa: "";
}

.fa-train {
  --fa: "";
}

.fa-eye-low-vision, .fa-low-vision {
  --fa: "";
}

.fa-crow {
  --fa: "";
}

.fa-sailboat {
  --fa: "";
}

.fa-window-restore {
  --fa: "";
}

.fa-square-plus, .fa-plus-square {
  --fa: "";
}

.fa-torii-gate {
  --fa: "";
}

.fa-frog {
  --fa: "";
}

.fa-bucket {
  --fa: "";
}

.fa-image {
  --fa: "";
}

.fa-microphone {
  --fa: "";
}

.fa-cow {
  --fa: "";
}

.fa-caret-up {
  --fa: "";
}

.fa-screwdriver {
  --fa: "";
}

.fa-folder-closed {
  --fa: "";
}

.fa-house-tsunami {
  --fa: "";
}

.fa-square-nfi {
  --fa: "";
}

.fa-arrow-up-from-ground-water {
  --fa: "";
}

.fa-martini-glass, .fa-glass-martini-alt {
  --fa: "";
}

.fa-square-binary {
  --fa: "";
}

.fa-rotate-left, .fa-rotate-back, .fa-rotate-backward, .fa-undo-alt {
  --fa: "";
}

.fa-table-columns, .fa-columns {
  --fa: "";
}

.fa-lemon {
  --fa: "";
}

.fa-head-side-mask {
  --fa: "";
}

.fa-handshake {
  --fa: "";
}

.fa-gem {
  --fa: "";
}

.fa-dolly, .fa-dolly-box {
  --fa: "";
}

.fa-smoking {
  --fa: "";
}

.fa-minimize, .fa-compress-arrows-alt {
  --fa: "";
}

.fa-monument {
  --fa: "";
}

.fa-snowplow {
  --fa: "";
}

.fa-angles-right, .fa-angle-double-right {
  --fa: "";
}

.fa-cannabis {
  --fa: "";
}

.fa-circle-play, .fa-play-circle {
  --fa: "";
}

.fa-tablets {
  --fa: "";
}

.fa-ethernet {
  --fa: "";
}

.fa-euro-sign, .fa-eur, .fa-euro {
  --fa: "";
}

.fa-chair {
  --fa: "";
}

.fa-circle-check, .fa-check-circle {
  --fa: "";
}

.fa-circle-stop, .fa-stop-circle {
  --fa: "";
}

.fa-compass-drafting, .fa-drafting-compass {
  --fa: "";
}

.fa-plate-wheat {
  --fa: "";
}

.fa-icicles {
  --fa: "";
}

.fa-person-shelter {
  --fa: "";
}

.fa-neuter {
  --fa: "";
}

.fa-id-badge {
  --fa: "";
}

.fa-marker {
  --fa: "";
}

.fa-face-laugh-beam, .fa-laugh-beam {
  --fa: "";
}

.fa-helicopter-symbol {
  --fa: "";
}

.fa-universal-access {
  --fa: "";
}

.fa-circle-chevron-up, .fa-chevron-circle-up {
  --fa: "";
}

.fa-lari-sign {
  --fa: "";
}

.fa-volcano {
  --fa: "";
}

.fa-person-walking-dashed-line-arrow-right {
  --fa: "";
}

.fa-sterling-sign, .fa-gbp, .fa-pound-sign {
  --fa: "";
}

.fa-viruses {
  --fa: "";
}

.fa-square-person-confined {
  --fa: "";
}

.fa-user-tie {
  --fa: "";
}

.fa-arrow-down-long, .fa-long-arrow-down {
  --fa: "";
}

.fa-tent-arrow-down-to-line {
  --fa: "";
}

.fa-certificate {
  --fa: "";
}

.fa-reply-all, .fa-mail-reply-all {
  --fa: "";
}

.fa-suitcase {
  --fa: "";
}

.fa-person-skating, .fa-skating {
  --fa: "";
}

.fa-filter-circle-dollar, .fa-funnel-dollar {
  --fa: "";
}

.fa-camera-retro {
  --fa: "";
}

.fa-circle-arrow-down, .fa-arrow-circle-down {
  --fa: "";
}

.fa-file-import, .fa-arrow-right-to-file {
  --fa: "";
}

.fa-square-arrow-up-right, .fa-external-link-square {
  --fa: "";
}

.fa-box-open {
  --fa: "";
}

.fa-scroll {
  --fa: "";
}

.fa-spa {
  --fa: "";
}

.fa-location-pin-lock {
  --fa: "";
}

.fa-pause {
  --fa: "";
}

.fa-hill-avalanche {
  --fa: "";
}

.fa-temperature-empty, .fa-temperature-0, .fa-thermometer-0, .fa-thermometer-empty {
  --fa: "";
}

.fa-bomb {
  --fa: "";
}

.fa-registered {
  --fa: "";
}

.fa-address-card, .fa-contact-card, .fa-vcard {
  --fa: "";
}

.fa-scale-unbalanced-flip, .fa-balance-scale-right {
  --fa: "";
}

.fa-subscript {
  --fa: "";
}

.fa-diamond-turn-right, .fa-directions {
  --fa: "";
}

.fa-burst {
  --fa: "";
}

.fa-house-laptop, .fa-laptop-house {
  --fa: "";
}

.fa-face-tired, .fa-tired {
  --fa: "";
}

.fa-money-bills {
  --fa: "";
}

.fa-smog {
  --fa: "";
}

.fa-crutch {
  --fa: "";
}

.fa-cloud-arrow-up, .fa-cloud-upload, .fa-cloud-upload-alt {
  --fa: "";
}

.fa-palette {
  --fa: "";
}

.fa-arrows-turn-right {
  --fa: "";
}

.fa-vest {
  --fa: "";
}

.fa-ferry {
  --fa: "";
}

.fa-arrows-down-to-people {
  --fa: "";
}

.fa-seedling, .fa-sprout {
  --fa: "";
}

.fa-left-right, .fa-arrows-alt-h {
  --fa: "";
}

.fa-boxes-packing {
  --fa: "";
}

.fa-circle-arrow-left, .fa-arrow-circle-left {
  --fa: "";
}

.fa-group-arrows-rotate {
  --fa: "";
}

.fa-bowl-food {
  --fa: "";
}

.fa-candy-cane {
  --fa: "";
}

.fa-arrow-down-wide-short, .fa-sort-amount-asc, .fa-sort-amount-down {
  --fa: "";
}

.fa-cloud-bolt, .fa-thunderstorm {
  --fa: "";
}

.fa-text-slash, .fa-remove-format {
  --fa: "";
}

.fa-face-smile-wink, .fa-smile-wink {
  --fa: "";
}

.fa-file-word {
  --fa: "";
}

.fa-file-powerpoint {
  --fa: "";
}

.fa-arrows-left-right, .fa-arrows-h {
  --fa: "";
}

.fa-house-lock {
  --fa: "";
}

.fa-cloud-arrow-down, .fa-cloud-download, .fa-cloud-download-alt {
  --fa: "";
}

.fa-children {
  --fa: "";
}

.fa-chalkboard, .fa-blackboard {
  --fa: "";
}

.fa-user-large-slash, .fa-user-alt-slash {
  --fa: "";
}

.fa-envelope-open {
  --fa: "";
}

.fa-handshake-simple-slash, .fa-handshake-alt-slash {
  --fa: "";
}

.fa-mattress-pillow {
  --fa: "";
}

.fa-guarani-sign {
  --fa: "";
}

.fa-arrows-rotate, .fa-refresh, .fa-sync {
  --fa: "";
}

.fa-fire-extinguisher {
  --fa: "";
}

.fa-cruzeiro-sign {
  --fa: "";
}

.fa-greater-than-equal {
  --fa: "";
}

.fa-shield-halved, .fa-shield-alt {
  --fa: "";
}

.fa-book-atlas, .fa-atlas {
  --fa: "";
}

.fa-virus {
  --fa: "";
}

.fa-envelope-circle-check {
  --fa: "";
}

.fa-layer-group {
  --fa: "";
}

.fa-arrows-to-dot {
  --fa: "";
}

.fa-archway {
  --fa: "";
}

.fa-heart-circle-check {
  --fa: "";
}

.fa-house-chimney-crack, .fa-house-damage {
  --fa: "";
}

.fa-file-zipper, .fa-file-archive {
  --fa: "";
}

.fa-square {
  --fa: "";
}

.fa-martini-glass-empty, .fa-glass-martini {
  --fa: "";
}

.fa-couch {
  --fa: "";
}

.fa-cedi-sign {
  --fa: "";
}

.fa-italic {
  --fa: "";
}

.fa-table-cells-column-lock {
  --fa: "";
}

.fa-church {
  --fa: "";
}

.fa-comments-dollar {
  --fa: "";
}

.fa-democrat {
  --fa: "";
}

.fa-z {
  --fa: "Z";
}

.fa-person-skiing, .fa-skiing {
  --fa: "";
}

.fa-road-lock {
  --fa: "";
}

.fa-a {
  --fa: "A";
}

.fa-temperature-arrow-down, .fa-temperature-down {
  --fa: "";
}

.fa-feather-pointed, .fa-feather-alt {
  --fa: "";
}

.fa-p {
  --fa: "P";
}

.fa-snowflake {
  --fa: "";
}

.fa-newspaper {
  --fa: "";
}

.fa-rectangle-ad, .fa-ad {
  --fa: "";
}

.fa-circle-arrow-right, .fa-arrow-circle-right {
  --fa: "";
}

.fa-filter-circle-xmark {
  --fa: "";
}

.fa-locust {
  --fa: "";
}

.fa-sort, .fa-unsorted {
  --fa: "";
}

.fa-list-ol, .fa-list-1-2, .fa-list-numeric {
  --fa: "";
}

.fa-person-dress-burst {
  --fa: "";
}

.fa-money-check-dollar, .fa-money-check-alt {
  --fa: "";
}

.fa-vector-square {
  --fa: "";
}

.fa-bread-slice {
  --fa: "";
}

.fa-language {
  --fa: "";
}

.fa-face-kiss-wink-heart, .fa-kiss-wink-heart {
  --fa: "";
}

.fa-filter {
  --fa: "";
}

.fa-question {
  --fa: "?";
}

.fa-file-signature {
  --fa: "";
}

.fa-up-down-left-right, .fa-arrows-alt {
  --fa: "";
}

.fa-house-chimney-user {
  --fa: "";
}

.fa-hand-holding-heart {
  --fa: "";
}

.fa-puzzle-piece {
  --fa: "";
}

.fa-money-check {
  --fa: "";
}

.fa-star-half-stroke, .fa-star-half-alt {
  --fa: "";
}

.fa-code {
  --fa: "";
}

.fa-whiskey-glass, .fa-glass-whiskey {
  --fa: "";
}

.fa-building-circle-exclamation {
  --fa: "";
}

.fa-magnifying-glass-chart {
  --fa: "";
}

.fa-arrow-up-right-from-square, .fa-external-link {
  --fa: "";
}

.fa-cubes-stacked {
  --fa: "";
}

.fa-won-sign, .fa-krw, .fa-won {
  --fa: "";
}

.fa-virus-covid {
  --fa: "";
}

.fa-austral-sign {
  --fa: "";
}

.fa-f {
  --fa: "F";
}

.fa-leaf {
  --fa: "";
}

.fa-road {
  --fa: "";
}

.fa-taxi, .fa-cab {
  --fa: "";
}

.fa-person-circle-plus {
  --fa: "";
}

.fa-chart-pie, .fa-pie-chart {
  --fa: "";
}

.fa-bolt-lightning {
  --fa: "";
}

.fa-sack-xmark {
  --fa: "";
}

.fa-file-excel {
  --fa: "";
}

.fa-file-contract {
  --fa: "";
}

.fa-fish-fins {
  --fa: "";
}

.fa-building-flag {
  --fa: "";
}

.fa-face-grin-beam, .fa-grin-beam {
  --fa: "";
}

.fa-object-ungroup {
  --fa: "";
}

.fa-poop {
  --fa: "";
}

.fa-location-pin, .fa-map-marker {
  --fa: "";
}

.fa-kaaba {
  --fa: "";
}

.fa-toilet-paper {
  --fa: "";
}

.fa-helmet-safety, .fa-hard-hat, .fa-hat-hard {
  --fa: "";
}

.fa-eject {
  --fa: "";
}

.fa-circle-right, .fa-arrow-alt-circle-right {
  --fa: "";
}

.fa-plane-circle-check {
  --fa: "";
}

.fa-face-rolling-eyes, .fa-meh-rolling-eyes {
  --fa: "";
}

.fa-object-group {
  --fa: "";
}

.fa-chart-line, .fa-line-chart {
  --fa: "";
}

.fa-mask-ventilator {
  --fa: "";
}

.fa-arrow-right {
  --fa: "";
}

.fa-signs-post, .fa-map-signs {
  --fa: "";
}

.fa-cash-register {
  --fa: "";
}

.fa-person-circle-question {
  --fa: "";
}

.fa-h {
  --fa: "H";
}

.fa-tarp {
  --fa: "";
}

.fa-screwdriver-wrench, .fa-tools {
  --fa: "";
}

.fa-arrows-to-eye {
  --fa: "";
}

.fa-plug-circle-bolt {
  --fa: "";
}

.fa-heart {
  --fa: "";
}

.fa-mars-and-venus {
  --fa: "";
}

.fa-house-user, .fa-home-user {
  --fa: "";
}

.fa-dumpster-fire {
  --fa: "";
}

.fa-house-crack {
  --fa: "";
}

.fa-martini-glass-citrus, .fa-cocktail {
  --fa: "";
}

.fa-face-surprise, .fa-surprise {
  --fa: "";
}

.fa-bottle-water {
  --fa: "";
}

.fa-circle-pause, .fa-pause-circle {
  --fa: "";
}

.fa-toilet-paper-slash {
  --fa: "";
}

.fa-apple-whole, .fa-apple-alt {
  --fa: "";
}

.fa-kitchen-set {
  --fa: "";
}

.fa-r {
  --fa: "R";
}

.fa-temperature-quarter, .fa-temperature-1, .fa-thermometer-1, .fa-thermometer-quarter {
  --fa: "";
}

.fa-cube {
  --fa: "";
}

.fa-bitcoin-sign {
  --fa: "";
}

.fa-shield-dog {
  --fa: "";
}

.fa-solar-panel {
  --fa: "";
}

.fa-lock-open {
  --fa: "";
}

.fa-elevator {
  --fa: "";
}

.fa-money-bill-transfer {
  --fa: "";
}

.fa-money-bill-trend-up {
  --fa: "";
}

.fa-house-flood-water-circle-arrow-right {
  --fa: "";
}

.fa-square-poll-horizontal, .fa-poll-h {
  --fa: "";
}

.fa-circle {
  --fa: "";
}

.fa-backward-fast, .fa-fast-backward {
  --fa: "";
}

.fa-recycle {
  --fa: "";
}

.fa-user-astronaut {
  --fa: "";
}

.fa-plane-slash {
  --fa: "";
}

.fa-trademark {
  --fa: "";
}

.fa-basketball, .fa-basketball-ball {
  --fa: "";
}

.fa-satellite-dish {
  --fa: "";
}

.fa-circle-up, .fa-arrow-alt-circle-up {
  --fa: "";
}

.fa-mobile-screen-button, .fa-mobile-alt {
  --fa: "";
}

.fa-volume-high, .fa-volume-up {
  --fa: "";
}

.fa-users-rays {
  --fa: "";
}

.fa-wallet {
  --fa: "";
}

.fa-clipboard-check {
  --fa: "";
}

.fa-file-audio {
  --fa: "";
}

.fa-burger, .fa-hamburger {
  --fa: "";
}

.fa-wrench {
  --fa: "";
}

.fa-bugs {
  --fa: "";
}

.fa-rupee-sign, .fa-rupee {
  --fa: "";
}

.fa-file-image {
  --fa: "";
}

.fa-circle-question, .fa-question-circle {
  --fa: "";
}

.fa-plane-departure {
  --fa: "";
}

.fa-handshake-slash {
  --fa: "";
}

.fa-book-bookmark {
  --fa: "";
}

.fa-code-branch {
  --fa: "";
}

.fa-hat-cowboy {
  --fa: "";
}

.fa-bridge {
  --fa: "";
}

.fa-phone-flip, .fa-phone-alt {
  --fa: "";
}

.fa-truck-front {
  --fa: "";
}

.fa-cat {
  --fa: "";
}

.fa-anchor-circle-exclamation {
  --fa: "";
}

.fa-truck-field {
  --fa: "";
}

.fa-route {
  --fa: "";
}

.fa-clipboard-question {
  --fa: "";
}

.fa-panorama {
  --fa: "";
}

.fa-comment-medical {
  --fa: "";
}

.fa-teeth-open {
  --fa: "";
}

.fa-file-circle-minus {
  --fa: "";
}

.fa-tags {
  --fa: "";
}

.fa-wine-glass {
  --fa: "";
}

.fa-forward-fast, .fa-fast-forward {
  --fa: "";
}

.fa-face-meh-blank, .fa-meh-blank {
  --fa: "";
}

.fa-square-parking, .fa-parking {
  --fa: "";
}

.fa-house-signal {
  --fa: "";
}

.fa-bars-progress, .fa-tasks-alt {
  --fa: "";
}

.fa-faucet-drip {
  --fa: "";
}

.fa-cart-flatbed, .fa-dolly-flatbed {
  --fa: "";
}

.fa-ban-smoking, .fa-smoking-ban {
  --fa: "";
}

.fa-terminal {
  --fa: "";
}

.fa-mobile-button {
  --fa: "";
}

.fa-house-medical-flag {
  --fa: "";
}

.fa-basket-shopping, .fa-shopping-basket {
  --fa: "";
}

.fa-tape {
  --fa: "";
}

.fa-bus-simple, .fa-bus-alt {
  --fa: "";
}

.fa-eye {
  --fa: "";
}

.fa-face-sad-cry, .fa-sad-cry {
  --fa: "";
}

.fa-audio-description {
  --fa: "";
}

.fa-person-military-to-person {
  --fa: "";
}

.fa-file-shield {
  --fa: "";
}

.fa-user-slash {
  --fa: "";
}

.fa-pen {
  --fa: "";
}

.fa-tower-observation {
  --fa: "";
}

.fa-file-code {
  --fa: "";
}

.fa-signal, .fa-signal-5, .fa-signal-perfect {
  --fa: "";
}

.fa-bus {
  --fa: "";
}

.fa-heart-circle-xmark {
  --fa: "";
}

.fa-house-chimney, .fa-home-lg {
  --fa: "";
}

.fa-window-maximize {
  --fa: "";
}

.fa-face-frown, .fa-frown {
  --fa: "";
}

.fa-prescription {
  --fa: "";
}

.fa-shop, .fa-store-alt {
  --fa: "";
}

.fa-floppy-disk, .fa-save {
  --fa: "";
}

.fa-vihara {
  --fa: "";
}

.fa-scale-unbalanced, .fa-balance-scale-left {
  --fa: "";
}

.fa-sort-up, .fa-sort-asc {
  --fa: "";
}

.fa-comment-dots, .fa-commenting {
  --fa: "";
}

.fa-plant-wilt {
  --fa: "";
}

.fa-diamond {
  --fa: "";
}

.fa-face-grin-squint, .fa-grin-squint {
  --fa: "";
}

.fa-hand-holding-dollar, .fa-hand-holding-usd {
  --fa: "";
}

.fa-chart-diagram {
  --fa: "";
}

.fa-bacterium {
  --fa: "";
}

.fa-hand-pointer {
  --fa: "";
}

.fa-drum-steelpan {
  --fa: "";
}

.fa-hand-scissors {
  --fa: "";
}

.fa-hands-praying, .fa-praying-hands {
  --fa: "";
}

.fa-arrow-rotate-right, .fa-arrow-right-rotate, .fa-arrow-rotate-forward, .fa-redo {
  --fa: "";
}

.fa-biohazard {
  --fa: "";
}

.fa-location-crosshairs, .fa-location {
  --fa: "";
}

.fa-mars-double {
  --fa: "";
}

.fa-child-dress {
  --fa: "";
}

.fa-users-between-lines {
  --fa: "";
}

.fa-lungs-virus {
  --fa: "";
}

.fa-face-grin-tears, .fa-grin-tears {
  --fa: "";
}

.fa-phone {
  --fa: "";
}

.fa-calendar-xmark, .fa-calendar-times {
  --fa: "";
}

.fa-child-reaching {
  --fa: "";
}

.fa-head-side-virus {
  --fa: "";
}

.fa-user-gear, .fa-user-cog {
  --fa: "";
}

.fa-arrow-up-1-9, .fa-sort-numeric-up {
  --fa: "";
}

.fa-door-closed {
  --fa: "";
}

.fa-shield-virus {
  --fa: "";
}

.fa-dice-six {
  --fa: "";
}

.fa-mosquito-net {
  --fa: "";
}

.fa-file-fragment {
  --fa: "";
}

.fa-bridge-water {
  --fa: "";
}

.fa-person-booth {
  --fa: "";
}

.fa-text-width {
  --fa: "";
}

.fa-hat-wizard {
  --fa: "";
}

.fa-pen-fancy {
  --fa: "";
}

.fa-person-digging, .fa-digging {
  --fa: "";
}

.fa-trash {
  --fa: "";
}

.fa-gauge-simple, .fa-gauge-simple-med, .fa-tachometer-average {
  --fa: "";
}

.fa-book-medical {
  --fa: "";
}

.fa-poo {
  --fa: "";
}

.fa-quote-right, .fa-quote-right-alt {
  --fa: "";
}

.fa-shirt, .fa-t-shirt, .fa-tshirt {
  --fa: "";
}

.fa-cubes {
  --fa: "";
}

.fa-divide {
  --fa: "";
}

.fa-tenge-sign, .fa-tenge {
  --fa: "";
}

.fa-headphones {
  --fa: "";
}

.fa-hands-holding {
  --fa: "";
}

.fa-hands-clapping {
  --fa: "";
}

.fa-republican {
  --fa: "";
}

.fa-arrow-left {
  --fa: "";
}

.fa-person-circle-xmark {
  --fa: "";
}

.fa-ruler {
  --fa: "";
}

.fa-align-left {
  --fa: "";
}

.fa-dice-d6 {
  --fa: "";
}

.fa-restroom {
  --fa: "";
}

.fa-j {
  --fa: "J";
}

.fa-users-viewfinder {
  --fa: "";
}

.fa-file-video {
  --fa: "";
}

.fa-up-right-from-square, .fa-external-link-alt {
  --fa: "";
}

.fa-table-cells, .fa-th {
  --fa: "";
}

.fa-file-pdf {
  --fa: "";
}

.fa-book-bible, .fa-bible {
  --fa: "";
}

.fa-o {
  --fa: "O";
}

.fa-suitcase-medical, .fa-medkit {
  --fa: "";
}

.fa-user-secret {
  --fa: "";
}

.fa-otter {
  --fa: "";
}

.fa-person-dress, .fa-female {
  --fa: "";
}

.fa-comment-dollar {
  --fa: "";
}

.fa-business-time, .fa-briefcase-clock {
  --fa: "";
}

.fa-table-cells-large, .fa-th-large {
  --fa: "";
}

.fa-book-tanakh, .fa-tanakh {
  --fa: "";
}

.fa-phone-volume, .fa-volume-control-phone {
  --fa: "";
}

.fa-hat-cowboy-side {
  --fa: "";
}

.fa-clipboard-user {
  --fa: "";
}

.fa-child {
  --fa: "";
}

.fa-lira-sign {
  --fa: "";
}

.fa-satellite {
  --fa: "";
}

.fa-plane-lock {
  --fa: "";
}

.fa-tag {
  --fa: "";
}

.fa-comment {
  --fa: "";
}

.fa-cake-candles, .fa-birthday-cake, .fa-cake {
  --fa: "";
}

.fa-envelope {
  --fa: "";
}

.fa-angles-up, .fa-angle-double-up {
  --fa: "";
}

.fa-paperclip {
  --fa: "";
}

.fa-arrow-right-to-city {
  --fa: "";
}

.fa-ribbon {
  --fa: "";
}

.fa-lungs {
  --fa: "";
}

.fa-arrow-up-9-1, .fa-sort-numeric-up-alt {
  --fa: "";
}

.fa-litecoin-sign {
  --fa: "";
}

.fa-border-none {
  --fa: "";
}

.fa-circle-nodes {
  --fa: "";
}

.fa-parachute-box {
  --fa: "";
}

.fa-indent {
  --fa: "";
}

.fa-truck-field-un {
  --fa: "";
}

.fa-hourglass, .fa-hourglass-empty {
  --fa: "";
}

.fa-mountain {
  --fa: "";
}

.fa-user-doctor, .fa-user-md {
  --fa: "";
}

.fa-circle-info, .fa-info-circle {
  --fa: "";
}

.fa-cloud-meatball {
  --fa: "";
}

.fa-camera, .fa-camera-alt {
  --fa: "";
}

.fa-square-virus {
  --fa: "";
}

.fa-meteor {
  --fa: "";
}

.fa-car-on {
  --fa: "";
}

.fa-sleigh {
  --fa: "";
}

.fa-arrow-down-1-9, .fa-sort-numeric-asc, .fa-sort-numeric-down {
  --fa: "";
}

.fa-hand-holding-droplet, .fa-hand-holding-water {
  --fa: "";
}

.fa-water {
  --fa: "";
}

.fa-calendar-check {
  --fa: "";
}

.fa-braille {
  --fa: "";
}

.fa-prescription-bottle-medical, .fa-prescription-bottle-alt {
  --fa: "";
}

.fa-landmark {
  --fa: "";
}

.fa-truck {
  --fa: "";
}

.fa-crosshairs {
  --fa: "";
}

.fa-person-cane {
  --fa: "";
}

.fa-tent {
  --fa: "";
}

.fa-vest-patches {
  --fa: "";
}

.fa-check-double {
  --fa: "";
}

.fa-arrow-down-a-z, .fa-sort-alpha-asc, .fa-sort-alpha-down {
  --fa: "";
}

.fa-money-bill-wheat {
  --fa: "";
}

.fa-cookie {
  --fa: "";
}

.fa-arrow-rotate-left, .fa-arrow-left-rotate, .fa-arrow-rotate-back, .fa-arrow-rotate-backward, .fa-undo {
  --fa: "";
}

.fa-hard-drive, .fa-hdd {
  --fa: "";
}

.fa-face-grin-squint-tears, .fa-grin-squint-tears {
  --fa: "";
}

.fa-dumbbell {
  --fa: "";
}

.fa-rectangle-list, .fa-list-alt {
  --fa: "";
}

.fa-tarp-droplet {
  --fa: "";
}

.fa-house-medical-circle-check {
  --fa: "";
}

.fa-person-skiing-nordic, .fa-skiing-nordic {
  --fa: "";
}

.fa-calendar-plus {
  --fa: "";
}

.fa-plane-arrival {
  --fa: "";
}

.fa-circle-left, .fa-arrow-alt-circle-left {
  --fa: "";
}

.fa-train-subway, .fa-subway {
  --fa: "";
}

.fa-chart-gantt {
  --fa: "";
}

.fa-indian-rupee-sign, .fa-indian-rupee, .fa-inr {
  --fa: "";
}

.fa-crop-simple, .fa-crop-alt {
  --fa: "";
}

.fa-money-bill-1, .fa-money-bill-alt {
  --fa: "";
}

.fa-left-long, .fa-long-arrow-alt-left {
  --fa: "";
}

.fa-dna {
  --fa: "";
}

.fa-virus-slash {
  --fa: "";
}

.fa-minus, .fa-subtract {
  --fa: "";
}

.fa-chess {
  --fa: "";
}

.fa-arrow-left-long, .fa-long-arrow-left {
  --fa: "";
}

.fa-plug-circle-check {
  --fa: "";
}

.fa-street-view {
  --fa: "";
}

.fa-franc-sign {
  --fa: "";
}

.fa-volume-off {
  --fa: "";
}

.fa-hands-asl-interpreting, .fa-american-sign-language-interpreting, .fa-asl-interpreting, .fa-hands-american-sign-language-interpreting {
  --fa: "";
}

.fa-gear, .fa-cog {
  --fa: "";
}

.fa-droplet-slash, .fa-tint-slash {
  --fa: "";
}

.fa-mosque {
  --fa: "";
}

.fa-mosquito {
  --fa: "";
}

.fa-star-of-david {
  --fa: "";
}

.fa-person-military-rifle {
  --fa: "";
}

.fa-cart-shopping, .fa-shopping-cart {
  --fa: "";
}

.fa-vials {
  --fa: "";
}

.fa-plug-circle-plus {
  --fa: "";
}

.fa-place-of-worship {
  --fa: "";
}

.fa-grip-vertical {
  --fa: "";
}

.fa-hexagon-nodes {
  --fa: "";
}

.fa-arrow-turn-up, .fa-level-up {
  --fa: "";
}

.fa-u {
  --fa: "U";
}

.fa-square-root-variable, .fa-square-root-alt {
  --fa: "";
}

.fa-clock, .fa-clock-four {
  --fa: "";
}

.fa-backward-step, .fa-step-backward {
  --fa: "";
}

.fa-pallet {
  --fa: "";
}

.fa-faucet {
  --fa: "";
}

.fa-baseball-bat-ball {
  --fa: "";
}

.fa-s {
  --fa: "S";
}

.fa-timeline {
  --fa: "";
}

.fa-keyboard {
  --fa: "";
}

.fa-caret-down {
  --fa: "";
}

.fa-house-chimney-medical, .fa-clinic-medical {
  --fa: "";
}

.fa-temperature-three-quarters, .fa-temperature-3, .fa-thermometer-3, .fa-thermometer-three-quarters {
  --fa: "";
}

.fa-mobile-screen, .fa-mobile-android-alt {
  --fa: "";
}

.fa-plane-up {
  --fa: "";
}

.fa-piggy-bank {
  --fa: "";
}

.fa-battery-half, .fa-battery-3 {
  --fa: "";
}

.fa-mountain-city {
  --fa: "";
}

.fa-coins {
  --fa: "";
}

.fa-khanda {
  --fa: "";
}

.fa-sliders, .fa-sliders-h {
  --fa: "";
}

.fa-folder-tree {
  --fa: "";
}

.fa-network-wired {
  --fa: "";
}

.fa-map-pin {
  --fa: "";
}

.fa-hamsa {
  --fa: "";
}

.fa-cent-sign {
  --fa: "";
}

.fa-flask {
  --fa: "";
}

.fa-person-pregnant {
  --fa: "";
}

.fa-wand-sparkles {
  --fa: "";
}

.fa-ellipsis-vertical, .fa-ellipsis-v {
  --fa: "";
}

.fa-ticket {
  --fa: "";
}

.fa-power-off {
  --fa: "";
}

.fa-right-long, .fa-long-arrow-alt-right {
  --fa: "";
}

.fa-flag-usa {
  --fa: "";
}

.fa-laptop-file {
  --fa: "";
}

.fa-tty, .fa-teletype {
  --fa: "";
}

.fa-diagram-next {
  --fa: "";
}

.fa-person-rifle {
  --fa: "";
}

.fa-house-medical-circle-exclamation {
  --fa: "";
}

.fa-closed-captioning {
  --fa: "";
}

.fa-person-hiking, .fa-hiking {
  --fa: "";
}

.fa-venus-double {
  --fa: "";
}

.fa-images {
  --fa: "";
}

.fa-calculator {
  --fa: "";
}

.fa-people-pulling {
  --fa: "";
}

.fa-n {
  --fa: "N";
}

.fa-cable-car, .fa-tram {
  --fa: "";
}

.fa-cloud-rain {
  --fa: "";
}

.fa-building-circle-xmark {
  --fa: "";
}

.fa-ship {
  --fa: "";
}

.fa-arrows-down-to-line {
  --fa: "";
}

.fa-download {
  --fa: "";
}

.fa-face-grin, .fa-grin {
  --fa: "";
}

.fa-delete-left, .fa-backspace {
  --fa: "";
}

.fa-eye-dropper, .fa-eye-dropper-empty, .fa-eyedropper {
  --fa: "";
}

.fa-file-circle-check {
  --fa: "";
}

.fa-forward {
  --fa: "";
}

.fa-mobile, .fa-mobile-android, .fa-mobile-phone {
  --fa: "";
}

.fa-face-meh, .fa-meh {
  --fa: "";
}

.fa-align-center {
  --fa: "";
}

.fa-book-skull, .fa-book-dead {
  --fa: "";
}

.fa-id-card, .fa-drivers-license {
  --fa: "";
}

.fa-outdent, .fa-dedent {
  --fa: "";
}

.fa-heart-circle-exclamation {
  --fa: "";
}

.fa-house, .fa-home, .fa-home-alt, .fa-home-lg-alt {
  --fa: "";
}

.fa-calendar-week {
  --fa: "";
}

.fa-laptop-medical {
  --fa: "";
}

.fa-b {
  --fa: "B";
}

.fa-file-medical {
  --fa: "";
}

.fa-dice-one {
  --fa: "";
}

.fa-kiwi-bird {
  --fa: "";
}

.fa-arrow-right-arrow-left, .fa-exchange {
  --fa: "";
}

.fa-rotate-right, .fa-redo-alt, .fa-rotate-forward {
  --fa: "";
}

.fa-utensils, .fa-cutlery {
  --fa: "";
}

.fa-arrow-up-wide-short, .fa-sort-amount-up {
  --fa: "";
}

.fa-mill-sign {
  --fa: "";
}

.fa-bowl-rice {
  --fa: "";
}

.fa-skull {
  --fa: "";
}

.fa-tower-broadcast, .fa-broadcast-tower {
  --fa: "";
}

.fa-truck-pickup {
  --fa: "";
}

.fa-up-long, .fa-long-arrow-alt-up {
  --fa: "";
}

.fa-stop {
  --fa: "";
}

.fa-code-merge {
  --fa: "";
}

.fa-upload {
  --fa: "";
}

.fa-hurricane {
  --fa: "";
}

.fa-mound {
  --fa: "";
}

.fa-toilet-portable {
  --fa: "";
}

.fa-compact-disc {
  --fa: "";
}

.fa-file-arrow-down, .fa-file-download {
  --fa: "";
}

.fa-caravan {
  --fa: "";
}

.fa-shield-cat {
  --fa: "";
}

.fa-bolt, .fa-zap {
  --fa: "";
}

.fa-glass-water {
  --fa: "";
}

.fa-oil-well {
  --fa: "";
}

.fa-vault {
  --fa: "";
}

.fa-mars {
  --fa: "";
}

.fa-toilet {
  --fa: "";
}

.fa-plane-circle-xmark {
  --fa: "";
}

.fa-yen-sign, .fa-cny, .fa-jpy, .fa-rmb, .fa-yen {
  --fa: "";
}

.fa-ruble-sign, .fa-rouble, .fa-rub, .fa-ruble {
  --fa: "";
}

.fa-sun {
  --fa: "";
}

.fa-guitar {
  --fa: "";
}

.fa-face-laugh-wink, .fa-laugh-wink {
  --fa: "";
}

.fa-horse-head {
  --fa: "";
}

.fa-bore-hole {
  --fa: "";
}

.fa-industry {
  --fa: "";
}

.fa-circle-down, .fa-arrow-alt-circle-down {
  --fa: "";
}

.fa-arrows-turn-to-dots {
  --fa: "";
}

.fa-florin-sign {
  --fa: "";
}

.fa-arrow-down-short-wide, .fa-sort-amount-desc, .fa-sort-amount-down-alt {
  --fa: "";
}

.fa-less-than {
  --fa: "<";
}

.fa-angle-down {
  --fa: "";
}

.fa-car-tunnel {
  --fa: "";
}

.fa-head-side-cough {
  --fa: "";
}

.fa-grip-lines {
  --fa: "";
}

.fa-thumbs-down {
  --fa: "";
}

.fa-user-lock {
  --fa: "";
}

.fa-arrow-right-long, .fa-long-arrow-right {
  --fa: "";
}

.fa-anchor-circle-xmark {
  --fa: "";
}

.fa-ellipsis, .fa-ellipsis-h {
  --fa: "";
}

.fa-chess-pawn {
  --fa: "";
}

.fa-kit-medical, .fa-first-aid {
  --fa: "";
}

.fa-person-through-window {
  --fa: "";
}

.fa-toolbox {
  --fa: "";
}

.fa-hands-holding-circle {
  --fa: "";
}

.fa-bug {
  --fa: "";
}

.fa-credit-card, .fa-credit-card-alt {
  --fa: "";
}

.fa-car, .fa-automobile {
  --fa: "";
}

.fa-hand-holding-hand {
  --fa: "";
}

.fa-book-open-reader, .fa-book-reader {
  --fa: "";
}

.fa-mountain-sun {
  --fa: "";
}

.fa-arrows-left-right-to-line {
  --fa: "";
}

.fa-dice-d20 {
  --fa: "";
}

.fa-truck-droplet {
  --fa: "";
}

.fa-file-circle-xmark {
  --fa: "";
}

.fa-temperature-arrow-up, .fa-temperature-up {
  --fa: "";
}

.fa-medal {
  --fa: "";
}

.fa-bed {
  --fa: "";
}

.fa-square-h, .fa-h-square {
  --fa: "";
}

.fa-podcast {
  --fa: "";
}

.fa-temperature-full, .fa-temperature-4, .fa-thermometer-4, .fa-thermometer-full {
  --fa: "";
}

.fa-bell {
  --fa: "";
}

.fa-superscript {
  --fa: "";
}

.fa-plug-circle-xmark {
  --fa: "";
}

.fa-star-of-life {
  --fa: "";
}

.fa-phone-slash {
  --fa: "";
}

.fa-paint-roller {
  --fa: "";
}

.fa-handshake-angle, .fa-hands-helping {
  --fa: "";
}

.fa-location-dot, .fa-map-marker-alt {
  --fa: "";
}

.fa-file {
  --fa: "";
}

.fa-greater-than {
  --fa: ">";
}

.fa-person-swimming, .fa-swimmer {
  --fa: "";
}

.fa-arrow-down {
  --fa: "";
}

.fa-droplet, .fa-tint {
  --fa: "";
}

.fa-eraser {
  --fa: "";
}

.fa-earth-americas, .fa-earth, .fa-earth-america, .fa-globe-americas {
  --fa: "";
}

.fa-person-burst {
  --fa: "";
}

.fa-dove {
  --fa: "";
}

.fa-battery-empty, .fa-battery-0 {
  --fa: "";
}

.fa-socks {
  --fa: "";
}

.fa-inbox {
  --fa: "";
}

.fa-section {
  --fa: "";
}

.fa-gauge-high, .fa-tachometer-alt, .fa-tachometer-alt-fast {
  --fa: "";
}

.fa-envelope-open-text {
  --fa: "";
}

.fa-hospital, .fa-hospital-alt, .fa-hospital-wide {
  --fa: "";
}

.fa-wine-bottle {
  --fa: "";
}

.fa-chess-rook {
  --fa: "";
}

.fa-bars-staggered, .fa-reorder, .fa-stream {
  --fa: "";
}

.fa-dharmachakra {
  --fa: "";
}

.fa-hotdog {
  --fa: "";
}

.fa-person-walking-with-cane, .fa-blind {
  --fa: "";
}

.fa-drum {
  --fa: "";
}

.fa-ice-cream {
  --fa: "";
}

.fa-heart-circle-bolt {
  --fa: "";
}

.fa-fax {
  --fa: "";
}

.fa-paragraph {
  --fa: "";
}

.fa-check-to-slot, .fa-vote-yea {
  --fa: "";
}

.fa-star-half {
  --fa: "";
}

.fa-boxes-stacked, .fa-boxes, .fa-boxes-alt {
  --fa: "";
}

.fa-link, .fa-chain {
  --fa: "";
}

.fa-ear-listen, .fa-assistive-listening-systems {
  --fa: "";
}

.fa-tree-city {
  --fa: "";
}

.fa-play {
  --fa: "";
}

.fa-font {
  --fa: "";
}

.fa-table-cells-row-lock {
  --fa: "";
}

.fa-rupiah-sign {
  --fa: "";
}

.fa-magnifying-glass, .fa-search {
  --fa: "";
}

.fa-table-tennis-paddle-ball, .fa-ping-pong-paddle-ball, .fa-table-tennis {
  --fa: "";
}

.fa-person-dots-from-line, .fa-diagnoses {
  --fa: "";
}

.fa-trash-can-arrow-up, .fa-trash-restore-alt {
  --fa: "";
}

.fa-naira-sign {
  --fa: "";
}

.fa-cart-arrow-down {
  --fa: "";
}

.fa-walkie-talkie {
  --fa: "";
}

.fa-file-pen, .fa-file-edit {
  --fa: "";
}

.fa-receipt {
  --fa: "";
}

.fa-square-pen, .fa-pen-square, .fa-pencil-square {
  --fa: "";
}

.fa-suitcase-rolling {
  --fa: "";
}

.fa-person-circle-exclamation {
  --fa: "";
}

.fa-chevron-down {
  --fa: "";
}

.fa-battery-full, .fa-battery, .fa-battery-5 {
  --fa: "";
}

.fa-skull-crossbones {
  --fa: "";
}

.fa-code-compare {
  --fa: "";
}

.fa-list-ul, .fa-list-dots {
  --fa: "";
}

.fa-school-lock {
  --fa: "";
}

.fa-tower-cell {
  --fa: "";
}

.fa-down-long, .fa-long-arrow-alt-down {
  --fa: "";
}

.fa-ranking-star {
  --fa: "";
}

.fa-chess-king {
  --fa: "";
}

.fa-person-harassing {
  --fa: "";
}

.fa-brazilian-real-sign {
  --fa: "";
}

.fa-landmark-dome, .fa-landmark-alt {
  --fa: "";
}

.fa-arrow-up {
  --fa: "";
}

.fa-tv, .fa-television, .fa-tv-alt {
  --fa: "";
}

.fa-shrimp {
  --fa: "";
}

.fa-list-check, .fa-tasks {
  --fa: "";
}

.fa-jug-detergent {
  --fa: "";
}

.fa-circle-user, .fa-user-circle {
  --fa: "";
}

.fa-user-shield {
  --fa: "";
}

.fa-wind {
  --fa: "";
}

.fa-car-burst, .fa-car-crash {
  --fa: "";
}

.fa-y {
  --fa: "Y";
}

.fa-person-snowboarding, .fa-snowboarding {
  --fa: "";
}

.fa-truck-fast, .fa-shipping-fast {
  --fa: "";
}

.fa-fish {
  --fa: "";
}

.fa-user-graduate {
  --fa: "";
}

.fa-circle-half-stroke, .fa-adjust {
  --fa: "";
}

.fa-clapperboard {
  --fa: "";
}

.fa-circle-radiation, .fa-radiation-alt {
  --fa: "";
}

.fa-baseball, .fa-baseball-ball {
  --fa: "";
}

.fa-jet-fighter-up {
  --fa: "";
}

.fa-diagram-project, .fa-project-diagram {
  --fa: "";
}

.fa-copy {
  --fa: "";
}

.fa-volume-xmark, .fa-volume-mute, .fa-volume-times {
  --fa: "";
}

.fa-hand-sparkles {
  --fa: "";
}

.fa-grip, .fa-grip-horizontal {
  --fa: "";
}

.fa-share-from-square, .fa-share-square {
  --fa: "";
}

.fa-child-combatant, .fa-child-rifle {
  --fa: "";
}

.fa-gun {
  --fa: "";
}

.fa-square-phone, .fa-phone-square {
  --fa: "";
}

.fa-plus, .fa-add {
  --fa: "+";
}

.fa-expand {
  --fa: "";
}

.fa-computer {
  --fa: "";
}

.fa-xmark, .fa-close, .fa-multiply, .fa-remove, .fa-times {
  --fa: "";
}

.fa-arrows-up-down-left-right, .fa-arrows {
  --fa: "";
}

.fa-chalkboard-user, .fa-chalkboard-teacher {
  --fa: "";
}

.fa-peso-sign {
  --fa: "";
}

.fa-building-shield {
  --fa: "";
}

.fa-baby {
  --fa: "";
}

.fa-users-line {
  --fa: "";
}

.fa-quote-left, .fa-quote-left-alt {
  --fa: "";
}

.fa-tractor {
  --fa: "";
}

.fa-trash-arrow-up, .fa-trash-restore {
  --fa: "";
}

.fa-arrow-down-up-lock {
  --fa: "";
}

.fa-lines-leaning {
  --fa: "";
}

.fa-ruler-combined {
  --fa: "";
}

.fa-copyright {
  --fa: "";
}

.fa-equals {
  --fa: "=";
}

.fa-blender {
  --fa: "";
}

.fa-teeth {
  --fa: "";
}

.fa-shekel-sign, .fa-ils, .fa-shekel, .fa-sheqel, .fa-sheqel-sign {
  --fa: "";
}

.fa-map {
  --fa: "";
}

.fa-rocket {
  --fa: "";
}

.fa-photo-film, .fa-photo-video {
  --fa: "";
}

.fa-folder-minus {
  --fa: "";
}

.fa-hexagon-nodes-bolt {
  --fa: "";
}

.fa-store {
  --fa: "";
}

.fa-arrow-trend-up {
  --fa: "";
}

.fa-plug-circle-minus {
  --fa: "";
}

.fa-sign-hanging, .fa-sign {
  --fa: "";
}

.fa-bezier-curve {
  --fa: "";
}

.fa-bell-slash {
  --fa: "";
}

.fa-tablet, .fa-tablet-android {
  --fa: "";
}

.fa-school-flag {
  --fa: "";
}

.fa-fill {
  --fa: "";
}

.fa-angle-up {
  --fa: "";
}

.fa-drumstick-bite {
  --fa: "";
}

.fa-holly-berry {
  --fa: "";
}

.fa-chevron-left {
  --fa: "";
}

.fa-bacteria {
  --fa: "";
}

.fa-hand-lizard {
  --fa: "";
}

.fa-notdef {
  --fa: "";
}

.fa-disease {
  --fa: "";
}

.fa-briefcase-medical {
  --fa: "";
}

.fa-genderless {
  --fa: "";
}

.fa-chevron-right {
  --fa: "";
}

.fa-retweet {
  --fa: "";
}

.fa-car-rear, .fa-car-alt {
  --fa: "";
}

.fa-pump-soap {
  --fa: "";
}

.fa-video-slash {
  --fa: "";
}

.fa-battery-quarter, .fa-battery-2 {
  --fa: "";
}

.fa-radio {
  --fa: "";
}

.fa-baby-carriage, .fa-carriage-baby {
  --fa: "";
}

.fa-traffic-light {
  --fa: "";
}

.fa-thermometer {
  --fa: "";
}

.fa-vr-cardboard {
  --fa: "";
}

.fa-hand-middle-finger {
  --fa: "";
}

.fa-percent, .fa-percentage {
  --fa: "%";
}

.fa-truck-moving {
  --fa: "";
}

.fa-glass-water-droplet {
  --fa: "";
}

.fa-display {
  --fa: "";
}

.fa-face-smile, .fa-smile {
  --fa: "";
}

.fa-thumbtack, .fa-thumb-tack {
  --fa: "";
}

.fa-trophy {
  --fa: "";
}

.fa-person-praying, .fa-pray {
  --fa: "";
}

.fa-hammer {
  --fa: "";
}

.fa-hand-peace {
  --fa: "";
}

.fa-rotate, .fa-sync-alt {
  --fa: "";
}

.fa-spinner {
  --fa: "";
}

.fa-robot {
  --fa: "";
}

.fa-peace {
  --fa: "";
}

.fa-gears, .fa-cogs {
  --fa: "";
}

.fa-warehouse {
  --fa: "";
}

.fa-arrow-up-right-dots {
  --fa: "";
}

.fa-splotch {
  --fa: "";
}

.fa-face-grin-hearts, .fa-grin-hearts {
  --fa: "";
}

.fa-dice-four {
  --fa: "";
}

.fa-sim-card {
  --fa: "";
}

.fa-transgender, .fa-transgender-alt {
  --fa: "";
}

.fa-mercury {
  --fa: "";
}

.fa-arrow-turn-down, .fa-level-down {
  --fa: "";
}

.fa-person-falling-burst {
  --fa: "";
}

.fa-award {
  --fa: "";
}

.fa-ticket-simple, .fa-ticket-alt {
  --fa: "";
}

.fa-building {
  --fa: "";
}

.fa-angles-left, .fa-angle-double-left {
  --fa: "";
}

.fa-qrcode {
  --fa: "";
}

.fa-clock-rotate-left, .fa-history {
  --fa: "";
}

.fa-face-grin-beam-sweat, .fa-grin-beam-sweat {
  --fa: "";
}

.fa-file-export, .fa-arrow-right-from-file {
  --fa: "";
}

.fa-shield, .fa-shield-blank {
  --fa: "";
}

.fa-arrow-up-short-wide, .fa-sort-amount-up-alt {
  --fa: "";
}

.fa-comment-nodes {
  --fa: "";
}

.fa-house-medical {
  --fa: "";
}

.fa-golf-ball-tee, .fa-golf-ball {
  --fa: "";
}

.fa-circle-chevron-left, .fa-chevron-circle-left {
  --fa: "";
}

.fa-house-chimney-window {
  --fa: "";
}

.fa-pen-nib {
  --fa: "";
}

.fa-tent-arrow-turn-left {
  --fa: "";
}

.fa-tents {
  --fa: "";
}

.fa-wand-magic, .fa-magic {
  --fa: "";
}

.fa-dog {
  --fa: "";
}

.fa-carrot {
  --fa: "";
}

.fa-moon {
  --fa: "";
}

.fa-wine-glass-empty, .fa-wine-glass-alt {
  --fa: "";
}

.fa-cheese {
  --fa: "";
}

.fa-yin-yang {
  --fa: "";
}

.fa-music {
  --fa: "";
}

.fa-code-commit {
  --fa: "";
}

.fa-temperature-low {
  --fa: "";
}

.fa-person-biking, .fa-biking {
  --fa: "";
}

.fa-broom {
  --fa: "";
}

.fa-shield-heart {
  --fa: "";
}

.fa-gopuram {
  --fa: "";
}

.fa-earth-oceania, .fa-globe-oceania {
  --fa: "";
}

.fa-square-xmark, .fa-times-square, .fa-xmark-square {
  --fa: "";
}

.fa-hashtag {
  --fa: "#";
}

.fa-up-right-and-down-left-from-center, .fa-expand-alt {
  --fa: "";
}

.fa-oil-can {
  --fa: "";
}

.fa-t {
  --fa: "T";
}

.fa-hippo {
  --fa: "";
}

.fa-chart-column {
  --fa: "";
}

.fa-infinity {
  --fa: "";
}

.fa-vial-circle-check {
  --fa: "";
}

.fa-person-arrow-down-to-line {
  --fa: "";
}

.fa-voicemail {
  --fa: "";
}

.fa-fan {
  --fa: "";
}

.fa-person-walking-luggage {
  --fa: "";
}

.fa-up-down, .fa-arrows-alt-v {
  --fa: "";
}

.fa-cloud-moon-rain {
  --fa: "";
}

.fa-calendar {
  --fa: "";
}

.fa-trailer {
  --fa: "";
}

.fa-bahai, .fa-haykal {
  --fa: "";
}

.fa-sd-card {
  --fa: "";
}

.fa-dragon {
  --fa: "";
}

.fa-shoe-prints {
  --fa: "";
}

.fa-circle-plus, .fa-plus-circle {
  --fa: "";
}

.fa-face-grin-tongue-wink, .fa-grin-tongue-wink {
  --fa: "";
}

.fa-hand-holding {
  --fa: "";
}

.fa-plug-circle-exclamation {
  --fa: "";
}

.fa-link-slash, .fa-chain-broken, .fa-chain-slash, .fa-unlink {
  --fa: "";
}

.fa-clone {
  --fa: "";
}

.fa-person-walking-arrow-loop-left {
  --fa: "";
}

.fa-arrow-up-z-a, .fa-sort-alpha-up-alt {
  --fa: "";
}

.fa-fire-flame-curved, .fa-fire-alt {
  --fa: "";
}

.fa-tornado {
  --fa: "";
}

.fa-file-circle-plus {
  --fa: "";
}

.fa-book-quran, .fa-quran {
  --fa: "";
}

.fa-anchor {
  --fa: "";
}

.fa-border-all {
  --fa: "";
}

.fa-face-angry, .fa-angry {
  --fa: "";
}

.fa-cookie-bite {
  --fa: "";
}

.fa-arrow-trend-down {
  --fa: "";
}

.fa-rss, .fa-feed {
  --fa: "";
}

.fa-draw-polygon {
  --fa: "";
}

.fa-scale-balanced, .fa-balance-scale {
  --fa: "";
}

.fa-gauge-simple-high, .fa-tachometer, .fa-tachometer-fast {
  --fa: "";
}

.fa-shower {
  --fa: "";
}

.fa-desktop, .fa-desktop-alt {
  --fa: "";
}

.fa-m {
  --fa: "M";
}

.fa-table-list, .fa-th-list {
  --fa: "";
}

.fa-comment-sms, .fa-sms {
  --fa: "";
}

.fa-book {
  --fa: "";
}

.fa-user-plus {
  --fa: "";
}

.fa-check {
  --fa: "";
}

.fa-battery-three-quarters, .fa-battery-4 {
  --fa: "";
}

.fa-house-circle-check {
  --fa: "";
}

.fa-angle-left {
  --fa: "";
}

.fa-diagram-successor {
  --fa: "";
}

.fa-truck-arrow-right {
  --fa: "";
}

.fa-arrows-split-up-and-left {
  --fa: "";
}

.fa-hand-fist, .fa-fist-raised {
  --fa: "";
}

.fa-cloud-moon {
  --fa: "";
}

.fa-briefcase {
  --fa: "";
}

.fa-person-falling {
  --fa: "";
}

.fa-image-portrait, .fa-portrait {
  --fa: "";
}

.fa-user-tag {
  --fa: "";
}

.fa-rug {
  --fa: "";
}

.fa-earth-europe, .fa-globe-europe {
  --fa: "";
}

.fa-cart-flatbed-suitcase, .fa-luggage-cart {
  --fa: "";
}

.fa-rectangle-xmark, .fa-rectangle-times, .fa-times-rectangle, .fa-window-close {
  --fa: "";
}

.fa-baht-sign {
  --fa: "";
}

.fa-book-open {
  --fa: "";
}

.fa-book-journal-whills, .fa-journal-whills {
  --fa: "";
}

.fa-handcuffs {
  --fa: "";
}

.fa-triangle-exclamation, .fa-exclamation-triangle, .fa-warning {
  --fa: "";
}

.fa-database {
  --fa: "";
}

.fa-share, .fa-mail-forward {
  --fa: "";
}

.fa-bottle-droplet {
  --fa: "";
}

.fa-mask-face {
  --fa: "";
}

.fa-hill-rockslide {
  --fa: "";
}

.fa-right-left, .fa-exchange-alt {
  --fa: "";
}

.fa-paper-plane {
  --fa: "";
}

.fa-road-circle-exclamation {
  --fa: "";
}

.fa-dungeon {
  --fa: "";
}

.fa-align-right {
  --fa: "";
}

.fa-money-bill-1-wave, .fa-money-bill-wave-alt {
  --fa: "";
}

.fa-life-ring {
  --fa: "";
}

.fa-hands, .fa-sign-language, .fa-signing {
  --fa: "";
}

.fa-calendar-day {
  --fa: "";
}

.fa-water-ladder, .fa-ladder-water, .fa-swimming-pool {
  --fa: "";
}

.fa-arrows-up-down, .fa-arrows-v {
  --fa: "";
}

.fa-face-grimace, .fa-grimace {
  --fa: "";
}

.fa-wheelchair-move, .fa-wheelchair-alt {
  --fa: "";
}

.fa-turn-down, .fa-level-down-alt {
  --fa: "";
}

.fa-person-walking-arrow-right {
  --fa: "";
}

.fa-square-envelope, .fa-envelope-square {
  --fa: "";
}

.fa-dice {
  --fa: "";
}

.fa-bowling-ball {
  --fa: "";
}

.fa-brain {
  --fa: "";
}

.fa-bandage, .fa-band-aid {
  --fa: "";
}

.fa-calendar-minus {
  --fa: "";
}

.fa-circle-xmark, .fa-times-circle, .fa-xmark-circle {
  --fa: "";
}

.fa-gifts {
  --fa: "";
}

.fa-hotel {
  --fa: "";
}

.fa-earth-asia, .fa-globe-asia {
  --fa: "";
}

.fa-id-card-clip, .fa-id-card-alt {
  --fa: "";
}

.fa-magnifying-glass-plus, .fa-search-plus {
  --fa: "";
}

.fa-thumbs-up {
  --fa: "";
}

.fa-user-clock {
  --fa: "";
}

.fa-hand-dots, .fa-allergies {
  --fa: "";
}

.fa-file-invoice {
  --fa: "";
}

.fa-window-minimize {
  --fa: "";
}

.fa-mug-saucer, .fa-coffee {
  --fa: "";
}

.fa-brush {
  --fa: "";
}

.fa-file-half-dashed {
  --fa: "";
}

.fa-mask {
  --fa: "";
}

.fa-magnifying-glass-minus, .fa-search-minus {
  --fa: "";
}

.fa-ruler-vertical {
  --fa: "";
}

.fa-user-large, .fa-user-alt {
  --fa: "";
}

.fa-train-tram {
  --fa: "";
}

.fa-user-nurse {
  --fa: "";
}

.fa-syringe {
  --fa: "";
}

.fa-cloud-sun {
  --fa: "";
}

.fa-stopwatch-20 {
  --fa: "";
}

.fa-square-full {
  --fa: "";
}

.fa-magnet {
  --fa: "";
}

.fa-jar {
  --fa: "";
}

.fa-note-sticky, .fa-sticky-note {
  --fa: "";
}

.fa-bug-slash {
  --fa: "";
}

.fa-arrow-up-from-water-pump {
  --fa: "";
}

.fa-bone {
  --fa: "";
}

.fa-table-cells-row-unlock {
  --fa: "";
}

.fa-user-injured {
  --fa: "";
}

.fa-face-sad-tear, .fa-sad-tear {
  --fa: "";
}

.fa-plane {
  --fa: "";
}

.fa-tent-arrows-down {
  --fa: "";
}

.fa-exclamation {
  --fa: "!";
}

.fa-arrows-spin {
  --fa: "";
}

.fa-print {
  --fa: "";
}

.fa-turkish-lira-sign, .fa-try, .fa-turkish-lira {
  --fa: "";
}

.fa-dollar-sign, .fa-dollar, .fa-usd {
  --fa: "$";
}

.fa-x {
  --fa: "X";
}

.fa-magnifying-glass-dollar, .fa-search-dollar {
  --fa: "";
}

.fa-users-gear, .fa-users-cog {
  --fa: "";
}

.fa-person-military-pointing {
  --fa: "";
}

.fa-building-columns, .fa-bank, .fa-institution, .fa-museum, .fa-university {
  --fa: "";
}

.fa-umbrella {
  --fa: "";
}

.fa-trowel {
  --fa: "";
}

.fa-d {
  --fa: "D";
}

.fa-stapler {
  --fa: "";
}

.fa-masks-theater, .fa-theater-masks {
  --fa: "";
}

.fa-kip-sign {
  --fa: "";
}

.fa-hand-point-left {
  --fa: "";
}

.fa-handshake-simple, .fa-handshake-alt {
  --fa: "";
}

.fa-jet-fighter, .fa-fighter-jet {
  --fa: "";
}

.fa-square-share-nodes, .fa-share-alt-square {
  --fa: "";
}

.fa-barcode {
  --fa: "";
}

.fa-plus-minus {
  --fa: "";
}

.fa-video, .fa-video-camera {
  --fa: "";
}

.fa-graduation-cap, .fa-mortar-board {
  --fa: "";
}

.fa-hand-holding-medical {
  --fa: "";
}

.fa-person-circle-check {
  --fa: "";
}

.fa-turn-up, .fa-level-up-alt {
  --fa: "";
}

.sr-only, .fa-sr-only, .sr-only-focusable:not(:focus), .fa-sr-only-focusable:not(:focus) {
  clip: rect(0, 0, 0, 0);
  white-space: nowrap;
  border-width: 0;
  width: 1px;
  height: 1px;
  margin: -1px;
  padding: 0;
  position: absolute;
  overflow: hidden;
}

.fa.fa-envelope-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-star-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-remove, .fa.fa-close {
  --fa: "";
}

.fa.fa-trash-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-clock-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-arrow-circle-o-down {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-arrow-circle-o-up {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-play-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-repeat, .fa.fa-rotate-right {
  --fa: "";
}

.fa.fa-list-alt {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-picture-o, .fa.fa-photo, .fa.fa-image {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-pencil-square-o, .fa.fa-edit {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-check-square-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-times-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-check-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-eye, .fa.fa-eye-slash {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-bar-chart, .fa.fa-bar-chart-o {
  --fa: "";
}

.fa.fa-twitter-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-facebook-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-thumbs-o-up {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-thumbs-o-down {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-heart-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-linkedin-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-github-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-lemon-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-square-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-bookmark-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-twitter, .fa.fa-facebook {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-facebook-f {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-hdd-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-o-right {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-o-left {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-o-up {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-o-down {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-files-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-floppy-o, .fa.fa-save {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-navicon, .fa.fa-reorder {
  --fa: "";
}

.fa.fa-pinterest, .fa.fa-pinterest-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-google-plus-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-google-plus {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-linkedin {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-tachometer, .fa.fa-dashboard {
  --fa: "";
}

.fa.fa-comment-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-comments-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-lightbulb-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-bell-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-text-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-building-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hospital-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-mobile, .fa.fa-mobile-phone {
  --fa: "";
}

.fa.fa-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-folder-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-folder-open-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-smile-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-frown-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-meh-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-keyboard-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-flag-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-star-half-o, .fa.fa-star-half-empty, .fa.fa-star-half-full {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-chain-broken, .fa.fa-unlink {
  --fa: "";
}

.fa.fa-calendar-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-maxcdn, .fa.fa-html5, .fa.fa-css3 {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-minus-square-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-compass, .fa.fa-caret-square-o-down {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-toggle-down {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-caret-square-o-up, .fa.fa-toggle-up {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-caret-square-o-right, .fa.fa-toggle-right {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-eur, .fa.fa-euro {
  --fa: "";
}

.fa.fa-usd, .fa.fa-dollar {
  --fa: "$";
}

.fa.fa-inr, .fa.fa-rupee {
  --fa: "";
}

.fa.fa-jpy, .fa.fa-cny, .fa.fa-rmb, .fa.fa-yen {
  --fa: "";
}

.fa.fa-rub, .fa.fa-ruble, .fa.fa-rouble {
  --fa: "";
}

.fa.fa-krw, .fa.fa-won {
  --fa: "";
}

.fa.fa-btc, .fa.fa-bitcoin {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-youtube-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-youtube, .fa.fa-xing, .fa.fa-xing-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-youtube-play {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-dropbox, .fa.fa-stack-overflow, .fa.fa-instagram, .fa.fa-flickr, .fa.fa-adn, .fa.fa-bitbucket, .fa.fa-bitbucket-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-tumblr, .fa.fa-tumblr-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-apple, .fa.fa-windows, .fa.fa-android, .fa.fa-linux, .fa.fa-dribbble, .fa.fa-skype, .fa.fa-foursquare, .fa.fa-trello, .fa.fa-gratipay, .fa.fa-gittip {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-sun-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-moon-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-vk, .fa.fa-weibo, .fa.fa-renren, .fa.fa-pagelines, .fa.fa-stack-exchange {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-arrow-circle-o-right {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-arrow-circle-o-left {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-caret-square-o-left, .fa.fa-toggle-left {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-dot-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-vimeo-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-try, .fa.fa-turkish-lira {
  --fa: "";
}

.fa.fa-plus-square-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-slack, .fa.fa-wordpress, .fa.fa-openid {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-institution, .fa.fa-bank {
  --fa: "";
}

.fa.fa-yahoo, .fa.fa-google, .fa.fa-reddit, .fa.fa-reddit-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-stumbleupon-circle, .fa.fa-stumbleupon, .fa.fa-delicious, .fa.fa-digg, .fa.fa-pied-piper-pp, .fa.fa-pied-piper-alt, .fa.fa-drupal, .fa.fa-joomla, .fa.fa-behance, .fa.fa-behance-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-steam, .fa.fa-steam-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-spotify, .fa.fa-deviantart, .fa.fa-soundcloud {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-file-pdf-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-word-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-excel-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-powerpoint-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-image-o, .fa.fa-file-photo-o, .fa.fa-file-picture-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-archive-o, .fa.fa-file-zip-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-audio-o, .fa.fa-file-sound-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-video-o, .fa.fa-file-movie-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-code-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-vine, .fa.fa-codepen, .fa.fa-jsfiddle {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-life-bouy, .fa.fa-life-buoy, .fa.fa-life-saver, .fa.fa-support {
  --fa: "";
}

.fa.fa-rebel, .fa.fa-ra {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-resistance {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-empire, .fa.fa-ge {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-git-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-git, .fa.fa-hacker-news, .fa.fa-y-combinator-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-yc-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-tencent-weibo, .fa.fa-qq, .fa.fa-weixin, .fa.fa-wechat {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-paper-plane-o, .fa.fa-send-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-circle-thin {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-futbol-o, .fa.fa-soccer-ball-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-slideshare, .fa.fa-twitch, .fa.fa-yelp {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-newspaper-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-paypal, .fa.fa-google-wallet, .fa.fa-cc-visa, .fa.fa-cc-mastercard, .fa.fa-cc-discover, .fa.fa-cc-amex, .fa.fa-cc-paypal, .fa.fa-cc-stripe {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-bell-slash-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-lastfm, .fa.fa-lastfm-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-ioxhost, .fa.fa-angellist {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-cc {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-ils, .fa.fa-shekel, .fa.fa-sheqel {
  --fa: "";
}

.fa.fa-buysellads, .fa.fa-connectdevelop, .fa.fa-dashcube, .fa.fa-forumbee, .fa.fa-leanpub, .fa.fa-sellsy, .fa.fa-shirtsinbulk, .fa.fa-simplybuilt, .fa.fa-skyatlas {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-diamond {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-transgender, .fa.fa-intersex {
  --fa: "";
}

.fa.fa-facebook-official {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-pinterest-p, .fa.fa-whatsapp {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-viacoin, .fa.fa-medium, .fa.fa-y-combinator, .fa.fa-yc {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-optin-monster, .fa.fa-opencart, .fa.fa-expeditedssl {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-battery-4, .fa.fa-battery {
  --fa: "";
}

.fa.fa-object-group, .fa.fa-object-ungroup, .fa.fa-sticky-note-o {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-cc-jcb, .fa.fa-cc-diners-club {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-hand-rock-o, .fa.fa-hand-grab-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-paper-o, .fa.fa-hand-stop-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-scissors-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-lizard-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-spock-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-pointer-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-peace-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-creative-commons, .fa.fa-gg, .fa.fa-gg-circle, .fa.fa-odnoklassniki, .fa.fa-odnoklassniki-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-get-pocket, .fa.fa-wikipedia-w, .fa.fa-safari, .fa.fa-chrome, .fa.fa-firefox, .fa.fa-opera, .fa.fa-internet-explorer {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-contao, .fa.fa-500px, .fa.fa-amazon {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-calendar-plus-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-calendar-minus-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-calendar-times-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-calendar-check-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-map-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-commenting-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-houzz, .fa.fa-vimeo {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-black-tie, .fa.fa-fonticons, .fa.fa-reddit-alien, .fa.fa-edge {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-codiepie, .fa.fa-modx, .fa.fa-fort-awesome, .fa.fa-usb, .fa.fa-product-hunt, .fa.fa-mixcloud, .fa.fa-scribd {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-pause-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-stop-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-bluetooth, .fa.fa-bluetooth-b, .fa.fa-gitlab, .fa.fa-wpbeginner, .fa.fa-wpforms, .fa.fa-envira, .fa.fa-wheelchair-alt {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-question-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-deafness, .fa.fa-hard-of-hearing {
  --fa: "";
}

.fa.fa-glide, .fa.fa-glide-g {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-viadeo, .fa.fa-viadeo-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-snapchat, .fa.fa-snapchat-ghost {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-snapchat-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-pied-piper, .fa.fa-first-order, .fa.fa-yoast, .fa.fa-themeisle, .fa.fa-google-plus-official {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-google-plus-circle {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-font-awesome, .fa.fa-fa {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-handshake-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-envelope-open-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-address-book-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-address-card-o, .fa.fa-vcard-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-user-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-user-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-id-card-o, .fa.fa-drivers-license-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-quora, .fa.fa-free-code-camp, .fa.fa-telegram {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-thermometer-4, .fa.fa-thermometer {
  --fa: "";
}

.fa.fa-bathtub, .fa.fa-s15 {
  --fa: "";
}

.fa.fa-window-maximize, .fa.fa-window-restore {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-window-close-o, .fa.fa-times-rectangle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-bandcamp, .fa.fa-grav, .fa.fa-etsy, .fa.fa-imdb, .fa.fa-ravelry, .fa.fa-eercast {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-snowflake-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-superpowers, .fa.fa-wpexplorer, .fa.fa-meetup {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

:root, :host {
  --fa-style-family-classic: "Font Awesome 6 Free";
  --fa-font-regular: normal 400 1em / 1 "Font Awesome 6 Free";
}

@font-face {
  font-family: "Font Awesome 6 Free";
  font-style: normal;
  font-weight: 400;
  font-display: block;
  src: url("../../../../../../vendor/fontawesome-free/webfonts/fa-regular-400.woff2?v=178429") format("woff2"), url("../../../../../../vendor/fontawesome-free/webfonts/fa-regular-400.ttf?v=178429") format("truetype");
}

.far, .fa-regular {
  font-weight: 400;
}

:root, :host {
  --fa-style-family-classic: "Font Awesome 6 Free";
  --fa-font-solid: normal 900 1em / 1 "Font Awesome 6 Free";
}

@font-face {
  font-family: "Font Awesome 6 Free";
  font-style: normal;
  font-weight: 900;
  font-display: block;
  src: url("../../../../../../vendor/fontawesome-free/webfonts/fa-solid-900.woff2?v=178429") format("woff2"), url("../../../../../../vendor/fontawesome-free/webfonts/fa-solid-900.ttf?v=178429") format("truetype");
}

.fas, [class^="icon-"], [class*=" icon-"], .fa-solid {
  font-weight: 900;
}

:root, :host {
  --fa-style-family-brands: "Font Awesome 6 Brands";
  --fa-font-brands: normal 400 1em / 1 "Font Awesome 6 Brands";
}

@font-face {
  font-family: "Font Awesome 6 Brands";
  font-style: normal;
  font-weight: 400;
  font-display: block;
  src: url("../../../../../../vendor/fontawesome-free/webfonts/fa-brands-400.woff2?v=178429") format("woff2"), url("../../../../../../vendor/fontawesome-free/webfonts/fa-brands-400.ttf?v=178429") format("truetype");
}

.fab, .icon-joomla, .fa-brands {
  font-weight: 400;
}

.fa-monero {
  --fa: "";
}

.fa-hooli {
  --fa: "";
}

.fa-yelp {
  --fa: "";
}

.fa-cc-visa {
  --fa: "";
}

.fa-lastfm {
  --fa: "";
}

.fa-shopware {
  --fa: "";
}

.fa-creative-commons-nc {
  --fa: "";
}

.fa-aws {
  --fa: "";
}

.fa-redhat {
  --fa: "";
}

.fa-yoast {
  --fa: "";
}

.fa-cloudflare {
  --fa: "";
}

.fa-ups {
  --fa: "";
}

.fa-pixiv {
  --fa: "";
}

.fa-wpexplorer {
  --fa: "";
}

.fa-dyalog {
  --fa: "";
}

.fa-bity {
  --fa: "";
}

.fa-stackpath {
  --fa: "";
}

.fa-buysellads {
  --fa: "";
}

.fa-first-order {
  --fa: "";
}

.fa-modx {
  --fa: "";
}

.fa-guilded {
  --fa: "";
}

.fa-vnv {
  --fa: "";
}

.fa-square-js, .fa-js-square {
  --fa: "";
}

.fa-microsoft {
  --fa: "";
}

.fa-qq {
  --fa: "";
}

.fa-orcid {
  --fa: "";
}

.fa-java {
  --fa: "";
}

.fa-invision {
  --fa: "";
}

.fa-creative-commons-pd-alt {
  --fa: "";
}

.fa-centercode {
  --fa: "";
}

.fa-glide-g {
  --fa: "";
}

.fa-drupal {
  --fa: "";
}

.fa-jxl {
  --fa: "";
}

.fa-dart-lang {
  --fa: "";
}

.fa-hire-a-helper {
  --fa: "";
}

.fa-creative-commons-by {
  --fa: "";
}

.fa-unity {
  --fa: "";
}

.fa-whmcs {
  --fa: "";
}

.fa-rocketchat {
  --fa: "";
}

.fa-vk {
  --fa: "";
}

.fa-untappd {
  --fa: "";
}

.fa-mailchimp {
  --fa: "";
}

.fa-css3-alt {
  --fa: "";
}

.fa-square-reddit, .fa-reddit-square {
  --fa: "";
}

.fa-vimeo-v {
  --fa: "";
}

.fa-contao {
  --fa: "";
}

.fa-square-font-awesome {
  --fa: "";
}

.fa-deskpro {
  --fa: "";
}

.fa-brave {
  --fa: "";
}

.fa-sistrix {
  --fa: "";
}

.fa-square-instagram, .fa-instagram-square {
  --fa: "";
}

.fa-battle-net {
  --fa: "";
}

.fa-the-red-yeti {
  --fa: "";
}

.fa-square-hacker-news, .fa-hacker-news-square {
  --fa: "";
}

.fa-edge {
  --fa: "";
}

.fa-threads {
  --fa: "";
}

.fa-napster {
  --fa: "";
}

.fa-square-snapchat, .fa-snapchat-square {
  --fa: "";
}

.fa-google-plus-g {
  --fa: "";
}

.fa-artstation {
  --fa: "";
}

.fa-markdown {
  --fa: "";
}

.fa-sourcetree {
  --fa: "";
}

.fa-google-plus {
  --fa: "";
}

.fa-diaspora {
  --fa: "";
}

.fa-foursquare {
  --fa: "";
}

.fa-stack-overflow {
  --fa: "";
}

.fa-github-alt {
  --fa: "";
}

.fa-phoenix-squadron {
  --fa: "";
}

.fa-pagelines {
  --fa: "";
}

.fa-algolia {
  --fa: "";
}

.fa-red-river {
  --fa: "";
}

.fa-creative-commons-sa {
  --fa: "";
}

.fa-safari {
  --fa: "";
}

.fa-google {
  --fa: "";
}

.fa-square-font-awesome-stroke, .fa-font-awesome-alt {
  --fa: "";
}

.fa-atlassian {
  --fa: "";
}

.fa-linkedin-in {
  --fa: "";
}

.fa-digital-ocean {
  --fa: "";
}

.fa-nimblr {
  --fa: "";
}

.fa-chromecast {
  --fa: "";
}

.fa-evernote {
  --fa: "";
}

.fa-hacker-news {
  --fa: "";
}

.fa-creative-commons-sampling {
  --fa: "";
}

.fa-adversal {
  --fa: "";
}

.fa-creative-commons {
  --fa: "";
}

.fa-watchman-monitoring {
  --fa: "";
}

.fa-fonticons {
  --fa: "";
}

.fa-weixin {
  --fa: "";
}

.fa-shirtsinbulk {
  --fa: "";
}

.fa-codepen {
  --fa: "";
}

.fa-git-alt {
  --fa: "";
}

.fa-lyft {
  --fa: "";
}

.fa-rev {
  --fa: "";
}

.fa-windows {
  --fa: "";
}

.fa-wizards-of-the-coast {
  --fa: "";
}

.fa-square-viadeo, .fa-viadeo-square {
  --fa: "";
}

.fa-meetup {
  --fa: "";
}

.fa-centos {
  --fa: "";
}

.fa-adn {
  --fa: "";
}

.fa-cloudsmith {
  --fa: "";
}

.fa-opensuse {
  --fa: "";
}

.fa-pied-piper-alt {
  --fa: "";
}

.fa-square-dribbble, .fa-dribbble-square {
  --fa: "";
}

.fa-codiepie {
  --fa: "";
}

.fa-node {
  --fa: "";
}

.fa-mix {
  --fa: "";
}

.fa-steam {
  --fa: "";
}

.fa-cc-apple-pay {
  --fa: "";
}

.fa-scribd {
  --fa: "";
}

.fa-debian {
  --fa: "";
}

.fa-openid {
  --fa: "";
}

.fa-instalod {
  --fa: "";
}

.fa-files-pinwheel {
  --fa: "";
}

.fa-expeditedssl {
  --fa: "";
}

.fa-sellcast {
  --fa: "";
}

.fa-square-twitter, .fa-twitter-square {
  --fa: "";
}

.fa-r-project {
  --fa: "";
}

.fa-delicious {
  --fa: "";
}

.fa-freebsd {
  --fa: "";
}

.fa-vuejs {
  --fa: "";
}

.fa-accusoft {
  --fa: "";
}

.fa-ioxhost {
  --fa: "";
}

.fa-fonticons-fi {
  --fa: "";
}

.fa-app-store {
  --fa: "";
}

.fa-cc-mastercard {
  --fa: "";
}

.fa-itunes-note {
  --fa: "";
}

.fa-golang {
  --fa: "";
}

.fa-kickstarter, .fa-square-kickstarter {
  --fa: "";
}

.fa-grav {
  --fa: "";
}

.fa-weibo {
  --fa: "";
}

.fa-uncharted {
  --fa: "";
}

.fa-firstdraft {
  --fa: "";
}

.fa-square-youtube, .fa-youtube-square {
  --fa: "";
}

.fa-wikipedia-w {
  --fa: "";
}

.fa-wpressr, .fa-rendact {
  --fa: "";
}

.fa-angellist {
  --fa: "";
}

.fa-galactic-republic {
  --fa: "";
}

.fa-nfc-directional {
  --fa: "";
}

.fa-skype {
  --fa: "";
}

.fa-joget {
  --fa: "";
}

.fa-fedora {
  --fa: "";
}

.fa-stripe-s {
  --fa: "";
}

.fa-meta {
  --fa: "";
}

.fa-laravel {
  --fa: "";
}

.fa-hotjar {
  --fa: "";
}

.fa-bluetooth-b {
  --fa: "";
}

.fa-square-letterboxd {
  --fa: "";
}

.fa-sticker-mule {
  --fa: "";
}

.fa-creative-commons-zero {
  --fa: "";
}

.fa-hips {
  --fa: "";
}

.fa-css {
  --fa: "";
}

.fa-behance {
  --fa: "";
}

.fa-reddit {
  --fa: "";
}

.fa-discord {
  --fa: "";
}

.fa-chrome {
  --fa: "";
}

.fa-app-store-ios {
  --fa: "";
}

.fa-cc-discover {
  --fa: "";
}

.fa-wpbeginner {
  --fa: "";
}

.fa-confluence {
  --fa: "";
}

.fa-shoelace {
  --fa: "";
}

.fa-mdb {
  --fa: "";
}

.fa-dochub {
  --fa: "";
}

.fa-accessible-icon {
  --fa: "";
}

.fa-ebay {
  --fa: "";
}

.fa-amazon {
  --fa: "";
}

.fa-unsplash {
  --fa: "";
}

.fa-yarn {
  --fa: "";
}

.fa-square-steam, .fa-steam-square {
  --fa: "";
}

.fa-500px {
  --fa: "";
}

.fa-square-vimeo, .fa-vimeo-square {
  --fa: "";
}

.fa-asymmetrik {
  --fa: "";
}

.fa-font-awesome, .fa-font-awesome-flag, .fa-font-awesome-logo-full {
  --fa: "";
}

.fa-gratipay {
  --fa: "";
}

.fa-apple {
  --fa: "";
}

.fa-hive {
  --fa: "";
}

.fa-gitkraken {
  --fa: "";
}

.fa-keybase {
  --fa: "";
}

.fa-apple-pay {
  --fa: "";
}

.fa-padlet {
  --fa: "";
}

.fa-amazon-pay {
  --fa: "";
}

.fa-square-github, .fa-github-square {
  --fa: "";
}

.fa-stumbleupon {
  --fa: "";
}

.fa-fedex {
  --fa: "";
}

.fa-phoenix-framework {
  --fa: "";
}

.fa-shopify {
  --fa: "";
}

.fa-neos {
  --fa: "";
}

.fa-square-threads {
  --fa: "";
}

.fa-hackerrank {
  --fa: "";
}

.fa-researchgate {
  --fa: "";
}

.fa-swift {
  --fa: "";
}

.fa-angular {
  --fa: "";
}

.fa-speakap {
  --fa: "";
}

.fa-angrycreative {
  --fa: "";
}

.fa-y-combinator {
  --fa: "";
}

.fa-empire {
  --fa: "";
}

.fa-envira {
  --fa: "";
}

.fa-google-scholar {
  --fa: "";
}

.fa-square-gitlab, .fa-gitlab-square {
  --fa: "";
}

.fa-studiovinari {
  --fa: "";
}

.fa-pied-piper {
  --fa: "";
}

.fa-wordpress {
  --fa: "";
}

.fa-product-hunt {
  --fa: "";
}

.fa-firefox {
  --fa: "";
}

.fa-linode {
  --fa: "";
}

.fa-goodreads {
  --fa: "";
}

.fa-square-odnoklassniki, .fa-odnoklassniki-square {
  --fa: "";
}

.fa-jsfiddle {
  --fa: "";
}

.fa-sith {
  --fa: "";
}

.fa-themeisle {
  --fa: "";
}

.fa-page4 {
  --fa: "";
}

.fa-hashnode {
  --fa: "";
}

.fa-react {
  --fa: "";
}

.fa-cc-paypal {
  --fa: "";
}

.fa-squarespace {
  --fa: "";
}

.fa-cc-stripe {
  --fa: "";
}

.fa-creative-commons-share {
  --fa: "";
}

.fa-bitcoin {
  --fa: "";
}

.fa-keycdn {
  --fa: "";
}

.fa-opera {
  --fa: "";
}

.fa-itch-io {
  --fa: "";
}

.fa-umbraco {
  --fa: "";
}

.fa-galactic-senate {
  --fa: "";
}

.fa-ubuntu {
  --fa: "";
}

.fa-draft2digital {
  --fa: "";
}

.fa-stripe {
  --fa: "";
}

.fa-houzz {
  --fa: "";
}

.fa-gg {
  --fa: "";
}

.fa-dhl {
  --fa: "";
}

.fa-square-pinterest, .fa-pinterest-square {
  --fa: "";
}

.fa-xing {
  --fa: "";
}

.fa-blackberry {
  --fa: "";
}

.fa-creative-commons-pd {
  --fa: "";
}

.fa-playstation {
  --fa: "";
}

.fa-quinscape {
  --fa: "";
}

.fa-less {
  --fa: "";
}

.fa-blogger-b {
  --fa: "";
}

.fa-opencart {
  --fa: "";
}

.fa-vine {
  --fa: "";
}

.fa-signal-messenger {
  --fa: "";
}

.fa-paypal {
  --fa: "";
}

.fa-gitlab {
  --fa: "";
}

.fa-typo3 {
  --fa: "";
}

.fa-reddit-alien {
  --fa: "";
}

.fa-yahoo {
  --fa: "";
}

.fa-dailymotion {
  --fa: "";
}

.fa-affiliatetheme {
  --fa: "";
}

.fa-pied-piper-pp {
  --fa: "";
}

.fa-bootstrap {
  --fa: "";
}

.fa-odnoklassniki {
  --fa: "";
}

.fa-nfc-symbol {
  --fa: "";
}

.fa-mintbit {
  --fa: "";
}

.fa-ethereum {
  --fa: "";
}

.fa-speaker-deck {
  --fa: "";
}

.fa-creative-commons-nc-eu {
  --fa: "";
}

.fa-patreon {
  --fa: "";
}

.fa-avianex {
  --fa: "";
}

.fa-ello {
  --fa: "";
}

.fa-gofore {
  --fa: "";
}

.fa-bimobject {
  --fa: "";
}

.fa-brave-reverse {
  --fa: "";
}

.fa-facebook-f {
  --fa: "";
}

.fa-square-google-plus, .fa-google-plus-square {
  --fa: "";
}

.fa-web-awesome {
  --fa: "";
}

.fa-mandalorian {
  --fa: "";
}

.fa-first-order-alt {
  --fa: "";
}

.fa-osi {
  --fa: "";
}

.fa-google-wallet {
  --fa: "";
}

.fa-d-and-d-beyond {
  --fa: "";
}

.fa-periscope {
  --fa: "";
}

.fa-fulcrum {
  --fa: "";
}

.fa-cloudscale {
  --fa: "";
}

.fa-forumbee {
  --fa: "";
}

.fa-mizuni {
  --fa: "";
}

.fa-schlix {
  --fa: "";
}

.fa-square-xing, .fa-xing-square {
  --fa: "";
}

.fa-bandcamp {
  --fa: "";
}

.fa-wpforms {
  --fa: "";
}

.fa-cloudversify {
  --fa: "";
}

.fa-usps {
  --fa: "";
}

.fa-megaport {
  --fa: "";
}

.fa-magento {
  --fa: "";
}

.fa-spotify {
  --fa: "";
}

.fa-optin-monster {
  --fa: "";
}

.fa-fly {
  --fa: "";
}

.fa-square-bluesky {
  --fa: "";
}

.fa-aviato {
  --fa: "";
}

.fa-itunes {
  --fa: "";
}

.fa-cuttlefish {
  --fa: "";
}

.fa-blogger {
  --fa: "";
}

.fa-flickr {
  --fa: "";
}

.fa-viber {
  --fa: "";
}

.fa-soundcloud {
  --fa: "";
}

.fa-digg {
  --fa: "";
}

.fa-tencent-weibo {
  --fa: "";
}

.fa-letterboxd {
  --fa: "";
}

.fa-symfony {
  --fa: "";
}

.fa-maxcdn {
  --fa: "";
}

.fa-etsy {
  --fa: "";
}

.fa-facebook-messenger {
  --fa: "";
}

.fa-audible {
  --fa: "";
}

.fa-think-peaks {
  --fa: "";
}

.fa-bilibili {
  --fa: "";
}

.fa-erlang {
  --fa: "";
}

.fa-x-twitter {
  --fa: "";
}

.fa-cotton-bureau {
  --fa: "";
}

.fa-dashcube {
  --fa: "";
}

.fa-42-group, .fa-innosoft {
  --fa: "";
}

.fa-stack-exchange {
  --fa: "";
}

.fa-elementor {
  --fa: "";
}

.fa-square-pied-piper, .fa-pied-piper-square {
  --fa: "";
}

.fa-creative-commons-nd {
  --fa: "";
}

.fa-palfed {
  --fa: "";
}

.fa-superpowers {
  --fa: "";
}

.fa-resolving {
  --fa: "";
}

.fa-xbox {
  --fa: "";
}

.fa-square-web-awesome-stroke {
  --fa: "";
}

.fa-searchengin {
  --fa: "";
}

.fa-tiktok {
  --fa: "";
}

.fa-square-facebook, .fa-facebook-square {
  --fa: "";
}

.fa-renren {
  --fa: "";
}

.fa-linux {
  --fa: "";
}

.fa-glide {
  --fa: "";
}

.fa-linkedin {
  --fa: "";
}

.fa-hubspot {
  --fa: "";
}

.fa-deploydog {
  --fa: "";
}

.fa-twitch {
  --fa: "";
}

.fa-flutter {
  --fa: "";
}

.fa-ravelry {
  --fa: "";
}

.fa-mixer {
  --fa: "";
}

.fa-square-lastfm, .fa-lastfm-square {
  --fa: "";
}

.fa-vimeo {
  --fa: "";
}

.fa-mendeley {
  --fa: "";
}

.fa-uniregistry {
  --fa: "";
}

.fa-figma {
  --fa: "";
}

.fa-creative-commons-remix {
  --fa: "";
}

.fa-cc-amazon-pay {
  --fa: "";
}

.fa-dropbox {
  --fa: "";
}

.fa-instagram {
  --fa: "";
}

.fa-cmplid {
  --fa: "";
}

.fa-upwork {
  --fa: "";
}

.fa-facebook {
  --fa: "";
}

.fa-gripfire {
  --fa: "";
}

.fa-jedi-order {
  --fa: "";
}

.fa-uikit {
  --fa: "";
}

.fa-fort-awesome-alt {
  --fa: "";
}

.fa-phabricator {
  --fa: "";
}

.fa-ussunnah {
  --fa: "";
}

.fa-earlybirds {
  --fa: "";
}

.fa-trade-federation {
  --fa: "";
}

.fa-autoprefixer {
  --fa: "";
}

.fa-whatsapp {
  --fa: "";
}

.fa-square-upwork {
  --fa: "";
}

.fa-slideshare {
  --fa: "";
}

.fa-google-play {
  --fa: "";
}

.fa-viadeo {
  --fa: "";
}

.fa-line {
  --fa: "";
}

.fa-google-drive {
  --fa: "";
}

.fa-servicestack {
  --fa: "";
}

.fa-simplybuilt {
  --fa: "";
}

.fa-bitbucket {
  --fa: "";
}

.fa-imdb {
  --fa: "";
}

.fa-deezer {
  --fa: "";
}

.fa-raspberry-pi {
  --fa: "";
}

.fa-jira {
  --fa: "";
}

.fa-docker {
  --fa: "";
}

.fa-screenpal {
  --fa: "";
}

.fa-bluetooth {
  --fa: "";
}

.fa-gitter {
  --fa: "";
}

.fa-d-and-d {
  --fa: "";
}

.fa-microblog {
  --fa: "";
}

.fa-cc-diners-club {
  --fa: "";
}

.fa-gg-circle {
  --fa: "";
}

.fa-pied-piper-hat {
  --fa: "";
}

.fa-kickstarter-k {
  --fa: "";
}

.fa-yandex {
  --fa: "";
}

.fa-readme {
  --fa: "";
}

.fa-html5 {
  --fa: "";
}

.fa-sellsy {
  --fa: "";
}

.fa-square-web-awesome {
  --fa: "";
}

.fa-sass {
  --fa: "";
}

.fa-wirsindhandwerk, .fa-wsh {
  --fa: "";
}

.fa-buromobelexperte {
  --fa: "";
}

.fa-salesforce {
  --fa: "";
}

.fa-octopus-deploy {
  --fa: "";
}

.fa-medapps {
  --fa: "";
}

.fa-ns8 {
  --fa: "";
}

.fa-pinterest-p {
  --fa: "";
}

.fa-apper {
  --fa: "";
}

.fa-fort-awesome {
  --fa: "";
}

.fa-waze {
  --fa: "";
}

.fa-bluesky {
  --fa: "";
}

.fa-cc-jcb {
  --fa: "";
}

.fa-snapchat, .fa-snapchat-ghost {
  --fa: "";
}

.fa-fantasy-flight-games {
  --fa: "";
}

.fa-rust {
  --fa: "";
}

.fa-wix {
  --fa: "";
}

.fa-square-behance, .fa-behance-square {
  --fa: "";
}

.fa-supple {
  --fa: "";
}

.fa-webflow {
  --fa: "";
}

.fa-rebel {
  --fa: "";
}

.fa-css3 {
  --fa: "";
}

.fa-staylinked {
  --fa: "";
}

.fa-kaggle {
  --fa: "";
}

.fa-space-awesome {
  --fa: "";
}

.fa-deviantart {
  --fa: "";
}

.fa-cpanel {
  --fa: "";
}

.fa-goodreads-g {
  --fa: "";
}

.fa-square-git, .fa-git-square {
  --fa: "";
}

.fa-square-tumblr, .fa-tumblr-square {
  --fa: "";
}

.fa-trello {
  --fa: "";
}

.fa-creative-commons-nc-jp {
  --fa: "";
}

.fa-get-pocket {
  --fa: "";
}

.fa-perbyte {
  --fa: "";
}

.fa-grunt {
  --fa: "";
}

.fa-weebly {
  --fa: "";
}

.fa-connectdevelop {
  --fa: "";
}

.fa-leanpub {
  --fa: "";
}

.fa-black-tie {
  --fa: "";
}

.fa-themeco {
  --fa: "";
}

.fa-python {
  --fa: "";
}

.fa-android {
  --fa: "";
}

.fa-bots {
  --fa: "";
}

.fa-free-code-camp {
  --fa: "";
}

.fa-hornbill {
  --fa: "";
}

.fa-js {
  --fa: "";
}

.fa-ideal {
  --fa: "";
}

.fa-git {
  --fa: "";
}

.fa-dev {
  --fa: "";
}

.fa-sketch {
  --fa: "";
}

.fa-yandex-international {
  --fa: "";
}

.fa-cc-amex {
  --fa: "";
}

.fa-uber {
  --fa: "";
}

.fa-github {
  --fa: "";
}

.fa-php {
  --fa: "";
}

.fa-alipay {
  --fa: "";
}

.fa-youtube {
  --fa: "";
}

.fa-skyatlas {
  --fa: "";
}

.fa-firefox-browser {
  --fa: "";
}

.fa-replyd {
  --fa: "";
}

.fa-suse {
  --fa: "";
}

.fa-jenkins {
  --fa: "";
}

.fa-twitter {
  --fa: "";
}

.fa-rockrms {
  --fa: "";
}

.fa-pinterest {
  --fa: "";
}

.fa-buffer {
  --fa: "";
}

.fa-npm {
  --fa: "";
}

.fa-yammer {
  --fa: "";
}

.fa-btc {
  --fa: "";
}

.fa-dribbble {
  --fa: "";
}

.fa-stumbleupon-circle {
  --fa: "";
}

.fa-internet-explorer {
  --fa: "";
}

.fa-stubber {
  --fa: "";
}

.fa-telegram, .fa-telegram-plane {
  --fa: "";
}

.fa-old-republic {
  --fa: "";
}

.fa-odysee {
  --fa: "";
}

.fa-square-whatsapp, .fa-whatsapp-square {
  --fa: "";
}

.fa-node-js {
  --fa: "";
}

.fa-edge-legacy {
  --fa: "";
}

.fa-slack, .fa-slack-hash {
  --fa: "";
}

.fa-medrt {
  --fa: "";
}

.fa-usb {
  --fa: "";
}

.fa-tumblr {
  --fa: "";
}

.fa-vaadin {
  --fa: "";
}

.fa-quora {
  --fa: "";
}

.fa-square-x-twitter {
  --fa: "";
}

.fa-reacteurope {
  --fa: "";
}

.fa-medium, .fa-medium-m {
  --fa: "";
}

.fa-amilia {
  --fa: "";
}

.fa-mixcloud {
  --fa: "";
}

.fa-flipboard {
  --fa: "";
}

.fa-viacoin {
  --fa: "";
}

.fa-critical-role {
  --fa: "";
}

.fa-sitrox {
  --fa: "";
}

.fa-discourse {
  --fa: "";
}

.fa-joomla {
  --fa: "";
}

.fa-mastodon {
  --fa: "";
}

.fa-airbnb {
  --fa: "";
}

.fa-wolf-pack-battalion {
  --fa: "";
}

.fa-buy-n-large {
  --fa: "";
}

.fa-gulp {
  --fa: "";
}

.fa-creative-commons-sampling-plus {
  --fa: "";
}

.fa-strava {
  --fa: "";
}

.fa-ember {
  --fa: "";
}

.fa-canadian-maple-leaf {
  --fa: "";
}

.fa-teamspeak {
  --fa: "";
}

.fa-pushed {
  --fa: "";
}

.fa-wordpress-simple {
  --fa: "";
}

.fa-nutritionix {
  --fa: "";
}

.fa-wodu {
  --fa: "";
}

.fa-google-pay {
  --fa: "";
}

.fa-intercom {
  --fa: "";
}

.fa-zhihu {
  --fa: "";
}

.fa-korvue {
  --fa: "";
}

.fa-pix {
  --fa: "";
}

.fa-steam-symbol {
  --fa: "";
}

.fa.fa-glass {
  --fa: "";
}

.fa.fa-envelope-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-star-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-remove, .fa.fa-close {
  --fa: "";
}

.fa.fa-gear {
  --fa: "";
}

.fa.fa-trash-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-home {
  --fa: "";
}

.fa.fa-file-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-clock-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-arrow-circle-o-down {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-arrow-circle-o-up {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-play-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-repeat, .fa.fa-rotate-right {
  --fa: "";
}

.fa.fa-refresh {
  --fa: "";
}

.fa.fa-list-alt {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-dedent {
  --fa: "";
}

.fa.fa-video-camera {
  --fa: "";
}

.fa.fa-picture-o, .fa.fa-photo, .fa.fa-image {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-map-marker {
  --fa: "";
}

.fa.fa-pencil-square-o, .fa.fa-edit {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-share-square-o {
  --fa: "";
}

.fa.fa-check-square-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-arrows {
  --fa: "";
}

.fa.fa-times-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-check-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-mail-forward {
  --fa: "";
}

.fa.fa-expand {
  --fa: "";
}

.fa.fa-compress {
  --fa: "";
}

.fa.fa-eye, .fa.fa-eye-slash {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-warning {
  --fa: "";
}

.fa.fa-calendar {
  --fa: "";
}

.fa.fa-arrows-v {
  --fa: "";
}

.fa.fa-arrows-h {
  --fa: "";
}

.fa.fa-bar-chart, .fa.fa-bar-chart-o {
  --fa: "";
}

.fa.fa-twitter-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-facebook-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-gears {
  --fa: "";
}

.fa.fa-thumbs-o-up {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-thumbs-o-down {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-heart-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-sign-out {
  --fa: "";
}

.fa.fa-linkedin-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-thumb-tack {
  --fa: "";
}

.fa.fa-external-link {
  --fa: "";
}

.fa.fa-sign-in {
  --fa: "";
}

.fa.fa-github-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-lemon-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-square-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-bookmark-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-twitter, .fa.fa-facebook {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-facebook {
  --fa: "";
}

.fa.fa-facebook-f {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-github {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-credit-card {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-feed {
  --fa: "";
}

.fa.fa-hdd-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-o-right {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-o-left {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-o-up {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-o-down {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-globe {
  --fa: "";
}

.fa.fa-tasks {
  --fa: "";
}

.fa.fa-arrows-alt {
  --fa: "";
}

.fa.fa-group {
  --fa: "";
}

.fa.fa-chain {
  --fa: "";
}

.fa.fa-cut {
  --fa: "";
}

.fa.fa-files-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-floppy-o, .fa.fa-save {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-navicon, .fa.fa-reorder {
  --fa: "";
}

.fa.fa-magic {
  --fa: "";
}

.fa.fa-pinterest, .fa.fa-pinterest-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-pinterest-square {
  --fa: "";
}

.fa.fa-google-plus-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-google-plus {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-money {
  --fa: "";
}

.fa.fa-unsorted {
  --fa: "";
}

.fa.fa-sort-desc {
  --fa: "";
}

.fa.fa-sort-asc {
  --fa: "";
}

.fa.fa-linkedin {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-rotate-left {
  --fa: "";
}

.fa.fa-legal {
  --fa: "";
}

.fa.fa-tachometer, .fa.fa-dashboard {
  --fa: "";
}

.fa.fa-comment-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-comments-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-flash {
  --fa: "";
}

.fa.fa-clipboard {
  --fa: "";
}

.fa.fa-lightbulb-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-exchange {
  --fa: "";
}

.fa.fa-cloud-download {
  --fa: "";
}

.fa.fa-cloud-upload {
  --fa: "";
}

.fa.fa-bell-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-cutlery {
  --fa: "";
}

.fa.fa-file-text-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-building-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hospital-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-tablet {
  --fa: "";
}

.fa.fa-mobile, .fa.fa-mobile-phone {
  --fa: "";
}

.fa.fa-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-mail-reply {
  --fa: "";
}

.fa.fa-github-alt {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-folder-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-folder-open-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-smile-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-frown-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-meh-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-keyboard-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-flag-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-mail-reply-all {
  --fa: "";
}

.fa.fa-star-half-o, .fa.fa-star-half-empty, .fa.fa-star-half-full {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-code-fork {
  --fa: "";
}

.fa.fa-chain-broken, .fa.fa-unlink {
  --fa: "";
}

.fa.fa-calendar-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-maxcdn, .fa.fa-html5, .fa.fa-css3 {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-unlock-alt {
  --fa: "";
}

.fa.fa-minus-square-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-level-up {
  --fa: "";
}

.fa.fa-level-down {
  --fa: "";
}

.fa.fa-pencil-square {
  --fa: "";
}

.fa.fa-external-link-square {
  --fa: "";
}

.fa.fa-compass, .fa.fa-caret-square-o-down {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-caret-square-o-down {
  --fa: "";
}

.fa.fa-toggle-down {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-caret-square-o-up, .fa.fa-toggle-up {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-caret-square-o-right, .fa.fa-toggle-right {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-eur, .fa.fa-euro {
  --fa: "";
}

.fa.fa-gbp {
  --fa: "";
}

.fa.fa-usd, .fa.fa-dollar {
  --fa: "$";
}

.fa.fa-inr, .fa.fa-rupee {
  --fa: "";
}

.fa.fa-jpy, .fa.fa-cny, .fa.fa-rmb, .fa.fa-yen {
  --fa: "";
}

.fa.fa-rub, .fa.fa-ruble, .fa.fa-rouble {
  --fa: "";
}

.fa.fa-krw, .fa.fa-won {
  --fa: "";
}

.fa.fa-btc, .fa.fa-bitcoin {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-bitcoin {
  --fa: "";
}

.fa.fa-file-text {
  --fa: "";
}

.fa.fa-sort-alpha-asc {
  --fa: "";
}

.fa.fa-sort-alpha-desc {
  --fa: "";
}

.fa.fa-sort-amount-asc {
  --fa: "";
}

.fa.fa-sort-amount-desc {
  --fa: "";
}

.fa.fa-sort-numeric-asc {
  --fa: "";
}

.fa.fa-sort-numeric-desc {
  --fa: "";
}

.fa.fa-youtube-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-youtube, .fa.fa-xing, .fa.fa-xing-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-xing-square {
  --fa: "";
}

.fa.fa-youtube-play {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-dropbox, .fa.fa-stack-overflow, .fa.fa-instagram, .fa.fa-flickr, .fa.fa-adn, .fa.fa-bitbucket, .fa.fa-bitbucket-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-bitbucket-square {
  --fa: "";
}

.fa.fa-tumblr, .fa.fa-tumblr-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-tumblr-square {
  --fa: "";
}

.fa.fa-long-arrow-down {
  --fa: "";
}

.fa.fa-long-arrow-up {
  --fa: "";
}

.fa.fa-long-arrow-left {
  --fa: "";
}

.fa.fa-long-arrow-right {
  --fa: "";
}

.fa.fa-apple, .fa.fa-windows, .fa.fa-android, .fa.fa-linux, .fa.fa-dribbble, .fa.fa-skype, .fa.fa-foursquare, .fa.fa-trello, .fa.fa-gratipay, .fa.fa-gittip {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-gittip {
  --fa: "";
}

.fa.fa-sun-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-moon-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-vk, .fa.fa-weibo, .fa.fa-renren, .fa.fa-pagelines, .fa.fa-stack-exchange {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-arrow-circle-o-right {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-arrow-circle-o-left {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-caret-square-o-left, .fa.fa-toggle-left {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-dot-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-vimeo-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-try, .fa.fa-turkish-lira {
  --fa: "";
}

.fa.fa-plus-square-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-slack, .fa.fa-wordpress, .fa.fa-openid {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-institution, .fa.fa-bank {
  --fa: "";
}

.fa.fa-mortar-board {
  --fa: "";
}

.fa.fa-yahoo, .fa.fa-google, .fa.fa-reddit, .fa.fa-reddit-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-reddit-square {
  --fa: "";
}

.fa.fa-stumbleupon-circle, .fa.fa-stumbleupon, .fa.fa-delicious, .fa.fa-digg, .fa.fa-pied-piper-pp, .fa.fa-pied-piper-alt, .fa.fa-drupal, .fa.fa-joomla, .fa.fa-behance, .fa.fa-behance-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-behance-square {
  --fa: "";
}

.fa.fa-steam, .fa.fa-steam-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-steam-square {
  --fa: "";
}

.fa.fa-automobile {
  --fa: "";
}

.fa.fa-cab {
  --fa: "";
}

.fa.fa-spotify, .fa.fa-deviantart, .fa.fa-soundcloud {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-file-pdf-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-word-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-excel-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-powerpoint-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-image-o, .fa.fa-file-photo-o, .fa.fa-file-picture-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-archive-o, .fa.fa-file-zip-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-audio-o, .fa.fa-file-sound-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-video-o, .fa.fa-file-movie-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-file-code-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-vine, .fa.fa-codepen, .fa.fa-jsfiddle {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-life-bouy, .fa.fa-life-buoy, .fa.fa-life-saver, .fa.fa-support {
  --fa: "";
}

.fa.fa-circle-o-notch {
  --fa: "";
}

.fa.fa-rebel, .fa.fa-ra {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-ra {
  --fa: "";
}

.fa.fa-resistance {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-empire, .fa.fa-ge {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-ge {
  --fa: "";
}

.fa.fa-git-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-git, .fa.fa-hacker-news, .fa.fa-y-combinator-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-y-combinator-square {
  --fa: "";
}

.fa.fa-yc-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-tencent-weibo, .fa.fa-qq, .fa.fa-weixin, .fa.fa-wechat {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-wechat {
  --fa: "";
}

.fa.fa-send {
  --fa: "";
}

.fa.fa-paper-plane-o, .fa.fa-send-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-circle-thin {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-header {
  --fa: "";
}

.fa.fa-futbol-o, .fa.fa-soccer-ball-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-slideshare, .fa.fa-twitch, .fa.fa-yelp {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-newspaper-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-paypal, .fa.fa-google-wallet, .fa.fa-cc-visa, .fa.fa-cc-mastercard, .fa.fa-cc-discover, .fa.fa-cc-amex, .fa.fa-cc-paypal, .fa.fa-cc-stripe {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-bell-slash-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-trash {
  --fa: "";
}

.fa.fa-copyright {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-eyedropper {
  --fa: "";
}

.fa.fa-area-chart {
  --fa: "";
}

.fa.fa-pie-chart {
  --fa: "";
}

.fa.fa-line-chart {
  --fa: "";
}

.fa.fa-lastfm, .fa.fa-lastfm-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-lastfm-square {
  --fa: "";
}

.fa.fa-ioxhost, .fa.fa-angellist {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-cc {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-ils, .fa.fa-shekel, .fa.fa-sheqel {
  --fa: "";
}

.fa.fa-buysellads, .fa.fa-connectdevelop, .fa.fa-dashcube, .fa.fa-forumbee, .fa.fa-leanpub, .fa.fa-sellsy, .fa.fa-shirtsinbulk, .fa.fa-simplybuilt, .fa.fa-skyatlas {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-diamond {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-transgender, .fa.fa-intersex {
  --fa: "";
}

.fa.fa-transgender-alt {
  --fa: "";
}

.fa.fa-facebook-official {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-pinterest-p, .fa.fa-whatsapp {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-hotel {
  --fa: "";
}

.fa.fa-viacoin, .fa.fa-medium, .fa.fa-y-combinator, .fa.fa-yc {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-yc {
  --fa: "";
}

.fa.fa-optin-monster, .fa.fa-opencart, .fa.fa-expeditedssl {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-battery-4, .fa.fa-battery {
  --fa: "";
}

.fa.fa-battery-3 {
  --fa: "";
}

.fa.fa-battery-2 {
  --fa: "";
}

.fa.fa-battery-1 {
  --fa: "";
}

.fa.fa-battery-0 {
  --fa: "";
}

.fa.fa-object-group, .fa.fa-object-ungroup, .fa.fa-sticky-note-o {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-sticky-note-o {
  --fa: "";
}

.fa.fa-cc-jcb, .fa.fa-cc-diners-club {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-clone {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hourglass-o {
  --fa: "";
}

.fa.fa-hourglass-1 {
  --fa: "";
}

.fa.fa-hourglass-2 {
  --fa: "";
}

.fa.fa-hourglass-3 {
  --fa: "";
}

.fa.fa-hand-rock-o, .fa.fa-hand-grab-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-paper-o, .fa.fa-hand-stop-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-scissors-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-lizard-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-spock-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-pointer-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-hand-peace-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-registered {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-creative-commons, .fa.fa-gg, .fa.fa-gg-circle, .fa.fa-odnoklassniki, .fa.fa-odnoklassniki-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-odnoklassniki-square {
  --fa: "";
}

.fa.fa-get-pocket, .fa.fa-wikipedia-w, .fa.fa-safari, .fa.fa-chrome, .fa.fa-firefox, .fa.fa-opera, .fa.fa-internet-explorer {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-television {
  --fa: "";
}

.fa.fa-contao, .fa.fa-500px, .fa.fa-amazon {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-calendar-plus-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-calendar-minus-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-calendar-times-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-calendar-check-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-map-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-commenting {
  --fa: "";
}

.fa.fa-commenting-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-houzz, .fa.fa-vimeo {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-vimeo {
  --fa: "";
}

.fa.fa-black-tie, .fa.fa-fonticons, .fa.fa-reddit-alien, .fa.fa-edge {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-credit-card-alt {
  --fa: "";
}

.fa.fa-codiepie, .fa.fa-modx, .fa.fa-fort-awesome, .fa.fa-usb, .fa.fa-product-hunt, .fa.fa-mixcloud, .fa.fa-scribd {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-pause-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-stop-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-bluetooth, .fa.fa-bluetooth-b, .fa.fa-gitlab, .fa.fa-wpbeginner, .fa.fa-wpforms, .fa.fa-envira, .fa.fa-wheelchair-alt {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-wheelchair-alt {
  --fa: "";
}

.fa.fa-question-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-volume-control-phone {
  --fa: "";
}

.fa.fa-asl-interpreting {
  --fa: "";
}

.fa.fa-deafness, .fa.fa-hard-of-hearing {
  --fa: "";
}

.fa.fa-glide, .fa.fa-glide-g {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-signing {
  --fa: "";
}

.fa.fa-viadeo, .fa.fa-viadeo-square {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-viadeo-square {
  --fa: "";
}

.fa.fa-snapchat, .fa.fa-snapchat-ghost {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-snapchat-ghost {
  --fa: "";
}

.fa.fa-snapchat-square {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-pied-piper, .fa.fa-first-order, .fa.fa-yoast, .fa.fa-themeisle, .fa.fa-google-plus-official {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-google-plus-official {
  --fa: "";
}

.fa.fa-google-plus-circle {
  --fa: "";
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-font-awesome, .fa.fa-fa {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-fa {
  --fa: "";
}

.fa.fa-handshake-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-envelope-open-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-linode {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-address-book-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-vcard {
  --fa: "";
}

.fa.fa-address-card-o, .fa.fa-vcard-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-user-circle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-user-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-id-badge {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-drivers-license {
  --fa: "";
}

.fa.fa-id-card-o, .fa.fa-drivers-license-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-quora, .fa.fa-free-code-camp, .fa.fa-telegram {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-thermometer-4, .fa.fa-thermometer {
  --fa: "";
}

.fa.fa-thermometer-3 {
  --fa: "";
}

.fa.fa-thermometer-2 {
  --fa: "";
}

.fa.fa-thermometer-1 {
  --fa: "";
}

.fa.fa-thermometer-0 {
  --fa: "";
}

.fa.fa-bathtub, .fa.fa-s15 {
  --fa: "";
}

.fa.fa-window-maximize, .fa.fa-window-restore {
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-times-rectangle {
  --fa: "";
}

.fa.fa-window-close-o, .fa.fa-times-rectangle-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-bandcamp, .fa.fa-grav, .fa.fa-etsy, .fa.fa-imdb, .fa.fa-ravelry, .fa.fa-eercast {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

.fa.fa-eercast {
  --fa: "";
}

.fa.fa-snowflake-o {
  --fa: "";
  font-family: "Font Awesome 6 Free";
  font-weight: 400;
}

.fa.fa-superpowers, .fa.fa-wpexplorer, .fa.fa-meetup {
  font-family: "Font Awesome 6 Brands";
  font-weight: 400;
}

[class^="icon-"], [class*=" icon-"] {
  speak: none;
}

[class^="icon-"].disabled, [class*=" icon-"].disabled, [class^="fa-"].disabled, [class*=" fa-"].disabled {
  font-weight: 400;
}

.icon-joomla:before {
  content: "";
}

.icon-accessible:before {
  content: "";
}

.icon-add:before {
  content: "+";
}

.icon-address-book:before, .icon-address:before {
  content: "";
}

.icon-align-justify:before {
  content: "";
}

.icon-angle-double-left:before {
  content: "";
}

.icon-angle-double-right:before {
  content: "";
}

.icon-angle-down:before {
  content: "";
}

.icon-angle-left:before {
  content: "";
}

.icon-angle-right:before {
  content: "";
}

.icon-angle-up:before {
  content: "";
}

.icon-apply:before {
  content: "";
}

.icon-archive:before {
  content: "";
}

.icon-arrow-down-2:before {
  content: "";
}

.icon-arrow-down-3:before {
  content: "";
}

.icon-arrow-down-4:before {
  content: "";
}

.icon-arrow-down:before {
  content: "";
}

.icon-arrow-first:before {
  content: "";
}

.icon-arrow-last:before {
  content: "";
}

.icon-arrow-left-2:before {
  content: "";
}

.icon-arrow-left-3:before {
  content: "";
}

.icon-arrow-left-4:before {
  content: "";
}

.icon-arrow-left:before {
  content: "";
}

.icon-arrow-right-2:before {
  content: "";
}

.icon-arrow-right-3:before {
  content: "";
}

.icon-arrow-right-4:before {
  content: "";
}

.icon-arrow-right:before {
  content: "";
}

.icon-arrow-up-2:before {
  content: "";
}

.icon-arrow-up-3:before {
  content: "";
}

.icon-arrow-up-4:before {
  content: "";
}

.icon-arrow-up:before {
  content: "";
}

.icon-arrows-alt:before {
  content: "";
}

.icon-asterisk:before {
  content: "";
}

.icon-attachment:before {
  content: "";
}

.icon-backward-2:before {
  content: "";
}

.icon-backward-circle:before {
  content: "";
}

.icon-backward:before {
  content: "";
}

.icon-ban-circle:before {
  content: "";
}

.icon-bars:before {
  content: "";
}

.icon-basket:before {
  content: "";
}

.icon-bell:before {
  content: "";
}

.icon-bolt:before {
  content: "";
}

.icon-book:before {
  content: "";
}

.icon-bookmark-2:before, .icon-bookmark:before {
  content: "";
}

.icon-box-add:before, .icon-box-remove:before {
  content: "";
}

.icon-briefcase:before {
  content: "";
}

.icon-broadcast:before {
  content: "";
}

.icon-brush:before {
  content: "";
}

.icon-bubble-quote:before {
  content: "";
}

.icon-bullhorn:before {
  content: "";
}

.icon-calendar-check:before, .icon-calendar-2:before {
  content: "";
}

.icon-calendar-3:before {
  content: "";
}

.icon-calendar-alt:before, .icon-calendar:before {
  content: "";
}

.icon-camera-2:before {
  content: "";
}

.icon-camera:before {
  content: "";
}

.icon-cancel-2:before {
  content: "";
}

.icon-cancel-circle:before {
  content: "";
}

.icon-cancel:before {
  content: "";
}

.icon-caret-down:before {
  content: "";
}

.icon-caret-up:before {
  content: "";
}

.icon-cart:before {
  content: "";
}

.icon-chart:before {
  content: "";
}

.icon-check-circle:before {
  content: "";
}

.icon-check-square:before {
  content: "";
}

.icon-check:before {
  content: "";
}

.icon-checkbox-checked:before {
  content: "";
}

.icon-checkbox-partial:before, .icon-checkbox-unchecked:before {
  content: "";
}

.icon-checkbox:before {
  content: "";
}

.icon-checkedout:before {
  content: "";
}

.icon-checkin:before {
  content: "";
}

.icon-checkmark-2:before, .icon-checkmark-circle:before {
  content: "";
}

.icon-checkmark:before {
  content: "";
}

.icon-chevron-down:before {
  content: "";
}

.icon-chevron-left:before {
  content: "";
}

.icon-chevron-right:before {
  content: "";
}

.icon-chevron-up:before {
  content: "";
}

.icon-circle:before {
  content: "";
}

.icon-clipboard:before {
  content: "";
}

.icon-clock:before {
  content: "";
}

.icon-cloud-download-alt:before, .icon-cloud-download:before {
  content: "";
}

.icon-cloud-upload:before {
  content: "";
}

.icon-cloud:before {
  content: "";
}

.icon-code:before {
  content: "";
}

.icon-code-branch:before {
  content: "";
}

.icon-cog:before {
  content: "";
}

.icon-cogs:before {
  content: "";
}

.icon-collapse:before {
  content: "+";
}

.icon-color-palette:before {
  content: "";
}

.icon-comment-dots:before {
  content: "";
}

.icon-comment:before {
  content: "";
}

.icon-comments-2:before {
  content: "";
}

.icon-comments:before {
  content: "";
}

.icon-compass:before {
  content: "";
}

.icon-connection:before {
  content: "";
}

.icon-contract-2:before {
  content: "";
}

.icon-contract:before {
  content: "";
}

.icon-copy:before {
  content: "";
}

.icon-credit-2:before, .icon-credit:before {
  content: "";
}

.icon-crop:before {
  content: "";
}

.icon-cube:before {
  content: "";
}

.icon-cubes:before {
  content: "";
}

.icon-dashboard:before {
  content: "";
}

.icon-database:before {
  content: "";
}

.icon-default:before {
  content: "";
}

.icon-delete:before {
  content: "";
}

.icon-desktop:before {
  content: "";
}

.icon-downarrow:before {
  content: "";
}

.icon-download:before {
  content: "";
}

.icon-drawer-2:before {
  content: "";
}

.icon-drawer:before {
  content: "";
}

.icon-edit:before {
  content: "";
}

.icon-ellipsis-h:before {
  content: "";
}

.icon-ellipsis-v:before {
  content: "";
}

.icon-enter:before {
  content: "";
}

.icon-envelope-open-text:before {
  content: "";
}

.icon-envelope-opened:before, .icon-envelope:before {
  content: "";
}

.icon-equalizer:before {
  content: "";
}

.icon-error:before {
  content: "!";
}

.icon-exclamation-circle:before {
  content: "";
}

.icon-exclamation-triangle:before {
  content: "";
}

.icon-exclamation:before {
  content: "!";
}

.icon-exit:before {
  content: "";
}

.icon-expand-2:before {
  content: "";
}

.icon-expand:before {
  content: "";
}

.icon-expired:before {
  content: "";
}

.icon-external-link-alt:before {
  content: "";
}

.icon-eye-2:before, .icon-eye-blocked:before, .icon-eye-close:before {
  content: "";
}

.icon-eye-open:before {
  content: "";
}

.icon-eye-slash:before {
  content: "";
}

.icon-eye:before {
  content: "";
}

.icon-fax:before {
  content: "";
}

.icon-featured:before {
  content: "";
}

.icon-feed:before {
  content: "";
}

.icon-file-2:before {
  content: "";
}

.icon-file-add:before {
  content: "+";
}

.icon-file-alt:before {
  content: "";
}

.icon-file-check:before {
  content: "";
}

.icon-file-minus:before {
  content: "";
}

.icon-file-plus:before {
  content: "+";
}

.icon-file-remove:before {
  content: "";
}

.icon-file:before {
  content: "";
}

.icon-filter:before {
  content: "";
}

.icon-first:before {
  content: "";
}

.icon-flag-2:before {
  content: "";
}

.icon-flag-3:before, .icon-flag:before {
  content: "";
}

.icon-flash:before {
  content: "";
}

.icon-folder-2:before {
  content: "";
}

.icon-folder-3:before {
  content: "";
}

.icon-folder-close:before, .icon-folder-minus:before {
  content: "";
}

.icon-folder-open:before {
  content: "";
}

.icon-folder-plus-2:before {
  content: "";
}

.icon-folder-plus:before {
  content: "";
}

.icon-folder-remove:before, .icon-folder:before {
  content: "";
}

.icon-forward-2:before {
  content: "";
}

.icon-forward-circle:before {
  content: "";
}

.icon-forward:before {
  content: "";
}

.icon-generic:before {
  content: "";
}

.icon-globe:before {
  content: "";
}

.icon-grid-2:before, .icon-grid-view-2:before {
  content: "";
}

.icon-grid-view:before, .icon-grid:before {
  content: "";
}

.icon-handshake:before {
  content: "";
}

.icon-health:before {
  content: "";
}

.icon-heart-2:before, .icon-heart:before {
  content: "";
}

.icon-help:before {
  content: "?";
}

.icon-hits:before {
  content: "";
}

.icon-home-2:before, .icon-home:before {
  content: "";
}

.icon-image:before, .icon-images:before {
  content: "";
}

.icon-info-2:before, .icon-info-circle:before {
  content: "";
}

.icon-info:before {
  content: "";
}

.icon-key:before {
  content: "";
}

.icon-lamp:before {
  content: "";
}

.icon-language:before {
  content: "";
}

.icon-last:before {
  content: "";
}

.icon-leftarrow:before {
  content: "";
}

.icon-lightbulb:before {
  content: "";
}

.icon-lightning:before {
  content: "";
}

.icon-link:before {
  content: "";
}

.icon-list-2:before {
  content: "";
}

.icon-list-view:before, .icon-list:before {
  content: "";
}

.icon-loading:before {
  content: "";
}

.icon-location:before {
  content: "";
}

.icon-lock:before, .icon-locked:before {
  content: "";
}

.icon-loop:before {
  content: "";
}

.icon-mail-2:before, .icon-mail:before {
  content: "";
}

.icon-map-signs:before {
  content: "";
}

.icon-menu-2:before {
  content: "";
}

.icon-menu-3:before {
  content: "";
}

.icon-menu:before {
  content: "";
}

.icon-minus-2:before {
  content: "";
}

.icon-minus-circle:before {
  content: "";
}

.icon-minus-sign:before, .icon-minus:before {
  content: "";
}

.icon-mobile:before {
  content: "";
}

.icon-move:before {
  content: "";
}

.icon-music:before {
  content: "";
}

.icon-new-tab-2:before {
  content: "";
}

.icon-new-tab:before {
  content: "";
}

.icon-new:before {
  content: "+";
}

.icon-next:before {
  content: "";
}

.icon-not-ok:before {
  content: "";
}

.icon-notification-2:before, .icon-notification-circle:before {
  content: "";
}

.icon-notification:before {
  content: "!";
}

.icon-ok:before {
  content: "";
}

.icon-open:before {
  content: "";
}

.icon-options:before {
  content: "";
}

.icon-out-2:before {
  content: "";
}

.icon-out-3:before {
  content: "";
}

.icon-out:before {
  content: "";
}

.icon-paint-brush:before, .icon-palette:before {
  content: "";
}

.icon-paperclip:before {
  content: "";
}

.icon-paragraph-center:before {
  content: "";
}

.icon-paragraph-justify:before {
  content: "";
}

.icon-paragraph-left:before {
  content: "";
}

.icon-paragraph-right:before {
  content: "";
}

.icon-pause-circle:before {
  content: "";
}

.icon-pause:before {
  content: "";
}

.icon-pen-square:before {
  content: "";
}

.icon-pencil-2:before, .icon-pencil-alt:before {
  content: "";
}

.icon-pencil:before {
  content: "";
}

.icon-pending:before {
  content: "";
}

.icon-phone-2:before {
  content: "";
}

.icon-phone:before {
  content: "";
}

.icon-picture:before, .icon-pictures:before {
  content: "";
}

.icon-pie:before {
  content: "";
}

.icon-pin:before {
  content: "";
}

.icon-play-2:before {
  content: "";
}

.icon-play-circle:before {
  content: "";
}

.icon-play:before {
  content: "";
}

.icon-plug:before {
  content: "";
}

.icon-plus-2:before {
  content: "+";
}

.icon-plus-circle:before {
  content: "";
}

.icon-plus-square:before {
  content: "";
}

.icon-plus:before {
  content: "+";
}

.icon-power-cord:before {
  content: "";
}

.icon-power-off:before {
  content: "";
}

.icon-previous:before {
  content: "";
}

.icon-print:before, .icon-printer:before {
  content: "";
}

.icon-project-diagram:before {
  content: "";
}

.icon-protected:before {
  content: "";
}

.icon-publish:before {
  content: "";
}

.icon-purge:before {
  content: "";
}

.icon-pushpin:before {
  content: "";
}

.icon-puzzle-piece:before, .icon-puzzle:before {
  content: "";
}

.icon-question-2:before, .icon-question-circle:before {
  content: "";
}

.icon-question-sign:before, .icon-question:before {
  content: "?";
}

.icon-quote-2:before {
  content: "";
}

.icon-quote-3:before {
  content: "";
}

.icon-quote:before, .icon-quotes-left:before {
  content: "";
}

.icon-quotes-right:before {
  content: "";
}

.icon-radio-checked:before {
  content: "";
}

.icon-radio-unchecked:before {
  content: "";
}

.icon-redo-2:before {
  content: "";
}

.icon-redo:before {
  content: "";
}

.icon-refresh:before {
  content: "";
}

.icon-register:before {
  content: "";
}

.icon-remove:before {
  content: "";
}

.icon-reply:before {
  content: "";
}

.icon-rightarrow:before {
  content: "";
}

.icon-rss:before {
  content: "";
}

.icon-save-copy:before {
  content: "";
}

.icon-save-new:before {
  content: "+";
}

.icon-save:before {
  content: "";
}

.icon-scissors:before {
  content: "";
}

.icon-screen:before {
  content: "";
}

.icon-screwdriver:before {
  content: "";
}

.icon-search-minus:before {
  content: "";
}

.icon-search-plus:before {
  content: "";
}

.icon-search:before {
  content: "";
}

.icon-select-file:before {
  content: "";
}

.icon-share-alt:before, .icon-share:before {
  content: "";
}

.icon-shield-alt:before, .icon-shield:before {
  content: "";
}

.icon-shuffle:before {
  content: "";
}

.icon-signup:before {
  content: "";
}

.icon-sliders-h:before {
  content: "";
}

.icon-smiley-2:before, .icon-smiley-happy-2:before, .icon-smiley-happy:before, .icon-smiley-neutral-2:before, .icon-smiley-neutral:before {
  content: "";
}

.icon-smiley-sad-2:before, .icon-smiley-sad:before {
  content: "";
}

.icon-smiley:before {
  content: "";
}

.icon-sort:before {
  content: "";
}

.icon-spinner:before {
  content: "";
}

.icon-square:before {
  content: "";
}

.icon-stack:before {
  content: "";
}

.icon-star-2:before {
  content: "";
}

.icon-star-empty:before, .icon-star:before {
  content: "";
}

.icon-stop-circle:before {
  content: "";
}

.icon-stop:before {
  content: "";
}

.icon-success:before {
  content: "";
}

.icon-support:before {
  content: "";
}

.icon-switch:before {
  content: "";
}

.icon-sync:before {
  content: "";
}

.icon-tablet:before {
  content: "";
}

.icon-tachometer-alt:before {
  content: "";
}

.icon-tag-2:before, .icon-tag:before {
  content: "";
}

.icon-tags-2:before, .icon-tags:before {
  content: "";
}

.icon-tasks:before {
  content: "";
}

.icon-text-width:before {
  content: "";
}

.icon-th:before {
  content: "";
}

.icon-th-large:before {
  content: "";
}

.icon-thumbs-down:before {
  content: "";
}

.icon-thumbs-up:before {
  content: "";
}

.icon-times:before {
  content: "";
}

.icon-toggle-off:before {
  content: "";
}

.icon-toggle-on:before {
  content: "";
}

.icon-tools:before {
  content: "";
}

.icon-trash:before {
  content: "";
}

.icon-tree-2:before {
  content: "";
}

.icon-tree:before {
  content: "";
}

.icon-trophy:before {
  content: "";
}

.icon-unarchive:before {
  content: "";
}

.icon-unblock:before {
  content: "";
}

.icon-undo-2:before, .icon-undo:before {
  content: "";
}

.icon-unfeatured:before {
  content: "";
}

.icon-universal:before, .icon-universal-access:before {
  content: "";
}

.icon-unlock-alt:before {
  content: "";
}

.icon-unlock:before {
  content: "";
}

.icon-unpublish:before {
  content: "";
}

.icon-uparrow:before {
  content: "";
}

.icon-upload:before {
  content: "";
}

.icon-user-circle:before {
  content: "";
}

.icon-user-edit:before {
  content: "";
}

.icon-user-lock:before {
  content: "";
}

.icon-user-tag:before {
  content: "";
}

.icon-user:before {
  content: "";
}

.icon-users-cog:before {
  content: "";
}

.icon-users:before {
  content: "";
}

.icon-vcard:before {
  content: "";
}

.icon-video-2:before {
  content: "";
}

.icon-video:before {
  content: "";
}

.icon-wand:before {
  content: "";
}

.icon-warning-2:before {
  content: "";
}

.icon-warning-circle:before {
  content: "";
}

.icon-warning:before {
  content: "";
}

.icon-wifi:before {
  content: "";
}

.icon-wrench:before {
  content: "";
}

.icon-zoom-in:before {
  content: "";
}

.icon-zoom-out:before {
  content: "";
}

html[dir="rtl"] .float-right {
  float: left;
}

input .icon-check-square:before {
  color: var(--icon-check-square-bg);
  background: var(--icon-check-square-color);
}

input .icon-square:before {
  color: var(--icon-square-bg);
  background: var(--icon-square-color);
}
